function [ret,x0,str]=outils(t,x,u,flag);
%OUTILS	is the M-file description of the SIMULINK system named OUTILS.
%	The block-diagram can be displayed by typing: OUTILS.
%
%	SYS=OUTILS(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes OUTILS to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling OUTILS with a FLAG of zero:
%	[SIZES]=OUTILS([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs.
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.2)
if(0 == (nargin + nargout))
     set_param(sys,'Location',[62,100,562,400])
     open_system(sys)
end;
set_param(sys,'BackGround',7)
set_param(sys,'algorithm',		'RK-45')
set_param(sys,'Start time',	'0.0')
set_param(sys,'Stop time',		'999999')
set_param(sys,'Min step size',	'0.0001')
set_param(sys,'Max step size',	'10')
set_param(sys,'Relative error','1e-3')
set_param(sys,'Return vars',	'')

add_block('built-in/Note',[sys,'/','OUTILS UTILISABLES POUR LE PFE 1994//95'])
set_param([sys,'/','OUTILS UTILISABLES POUR LE PFE 1994//95'],...
		'ForeGround',2,...
		'Font Size',18,...
		'position',[250,5,251,6])


%     Subsystem  'Produit vectoriel'.

new_system([sys,'/','Produit vectoriel'])
set_param([sys,'/','Produit vectoriel'],'Location',[45,105,265,270])

add_block('built-in/Mux',[sys,'/','Produit vectoriel/Mux1'])
set_param([sys,'/','Produit vectoriel/Mux1'],...
		'hide name',0,...
		'inputs','[3 3]',...
		'position',[65,55,105,130])

add_block('built-in/MATLAB Fcn',[sys,'/','Produit vectoriel/MATLAB Fcn1'])
set_param([sys,'/','Produit vectoriel/MATLAB Fcn1'],...
		'hide name',0,...
		'MATLAB Fcn','cross(u(1:3),u(4:6))',...
		'Output Width','3',...
		'position',[130,80,180,110])

add_block('built-in/Inport',[sys,'/','Produit vectoriel/in_1'])
set_param([sys,'/','Produit vectoriel/in_1'],...
		'position',[15,65,35,85])

add_block('built-in/Outport',[sys,'/','Produit vectoriel/out_1'])
set_param([sys,'/','Produit vectoriel/out_1'],...
		'position',[210,85,230,105])

add_block('built-in/Inport',[sys,'/','Produit vectoriel/in_2'])
set_param([sys,'/','Produit vectoriel/in_2'],...
		'Port','2',...
		'position',[15,100,35,120])
add_line([sys,'/','Produit vectoriel'],[110,95;120,95])
add_line([sys,'/','Produit vectoriel'],[40,75;55,75])
add_line([sys,'/','Produit vectoriel'],[185,95;200,95])
add_line([sys,'/','Produit vectoriel'],[40,110;55,110])
set_param([sys,'/','Produit vectoriel'],...
		'Mask Display','Produit\nVECTORIEL')


%     Finished composite block 'Produit vectoriel'.

set_param([sys,'/','Produit vectoriel'],...
		'position',[25,58,105,107])


%     Subsystem  ['Calcul champ magntique',13,'terrestre'].

new_system([sys,'/',['Calcul champ magntique',13,'terrestre']])
set_param([sys,'/',['Calcul champ magntique',13,'terrestre']],'Location',[4,42,628,468])

add_block('built-in/MATLAB Fcn',[sys,'/',['Calcul champ magntique',13,'terrestre/MATLAB Fcn']])
set_param([sys,'/',['Calcul champ magntique',13,'terrestre/MATLAB Fcn']],...
		'hide name',0,...
		'MATLAB Fcn','passage(u)',...
		'Output Width','3',...
		'Mask Display','CHANGEMENT\nDE BASE',...
		'position',[300,92,400,138])

add_block('built-in/Outport',[sys,'/',['Calcul champ magntique',13,'terrestre/out_1']])
set_param([sys,'/',['Calcul champ magntique',13,'terrestre/out_1']],...
		'Mask Display','',...
		'position',[445,105,465,125])

add_block('built-in/Note',[sys,'/',['Calcul champ magntique',13,'terrestre/Champ magntique',13,'terrestre',13,'(repre satellite)']])
set_param([sys,'/',['Calcul champ magntique',13,'terrestre/Champ magntique',13,'terrestre',13,'(repre satellite)']],...
		'position',[526,100,527,101])

add_block('built-in/State-space',[sys,'/',['Calcul champ magntique',13,'terrestre/Matrix gain.4']])
set_param([sys,'/',['Calcul champ magntique',13,'terrestre/Matrix gain.4']],...
		'A','[]',...
		'B','[]',...
		'C','[]',...
		'D','K',...
		'Mask Display','matrice',...
		'Mask Type','Matrix gain')
set_param([sys,'/',['Calcul champ magntique',13,'terrestre/Matrix gain.4']],...
		'Mask Dialogue','Matrix Gain:|Gain matrix:',...
		'Mask Translate','K = @1;',...
		'Mask Help','Multiplies input vector by entered matrix to produce output vector.')
set_param([sys,'/',['Calcul champ magntique',13,'terrestre/Matrix gain.4']],...
		'Mask Entries','[1 0 0 0 0 0;0 0 1 0 0 0 ;0 0 0 0 1 0]\/',...
		'position',[130,118,185,152])

add_block('built-in/Mux',[sys,'/',['Calcul champ magntique',13,'terrestre/Mux4']])
set_param([sys,'/',['Calcul champ magntique',13,'terrestre/Mux4']],...
		'hide name',0,...
		'inputs','[3 3]',...
		'position',[220,65,255,160])

add_block('built-in/Note',[sys,'/',['Calcul champ magntique',13,'terrestre/Champ magntique',13,'terrestre',13,'(repre orbital)']])
set_param([sys,'/',['Calcul champ magntique',13,'terrestre/Champ magntique',13,'terrestre',13,'(repre orbital)']],...
		'position',[155,45,156,46])

add_block('built-in/Inport',[sys,'/',['Calcul champ magntique',13,'terrestre/in_1']])
set_param([sys,'/',['Calcul champ magntique',13,'terrestre/in_1']],...
		'position',[65,80,85,100])

add_block('built-in/Note',[sys,'/',['Calcul champ magntique',13,'terrestre/Vecteur',13,'d''tat']])
set_param([sys,'/',['Calcul champ magntique',13,'terrestre/Vecteur',13,'d''tat']],...
		'position',[108,105,109,106])

add_block('built-in/Inport',[sys,'/',['Calcul champ magntique',13,'terrestre/in_2']])
set_param([sys,'/',['Calcul champ magntique',13,'terrestre/in_2']],...
		'Port','2',...
		'position',[65,125,85,145])

add_block('built-in/Note',[sys,'/',['Calcul champ magntique',13,'terrestre/Cette boite fournit en sortie le champ magntique terrestre calcul dans les axes satellite',13,'connaissant en entre:',13,'',13,'1 Le champ magntique en repre orbital (X Y Z )',13,'',13,'2  le vecteur d''tat  6 composantes (roulis  v_roulis tangage v_tangage lacet v_lacet)  ']])
set_param([sys,'/',['Calcul champ magntique',13,'terrestre/Cette boite fournit en sortie le champ magntique terrestre calcul dans les axes satellite',13,'connaissant en entre:',13,'',13,'1 Le champ magntique en repre orbital (X Y Z )',13,'',13,'2  le vecteur d''tat  6 composantes (roulis  v_roulis tangage v_tangage lacet v_lacet)  ']],...
		'ForeGround',4)
set_param([sys,'/',['Calcul champ magntique',13,'terrestre/Cette boite fournit en sortie le champ magntique terrestre calcul dans les axes satellite',13,'connaissant en entre:',13,'',13,'1 Le champ magntique en repre orbital (X Y Z )',13,'',13,'2  le vecteur d''tat  6 composantes (roulis  v_roulis tangage v_tangage lacet v_lacet)  ']],...
		'Font Size',12)
set_param([sys,'/',['Calcul champ magntique',13,'terrestre/Cette boite fournit en sortie le champ magntique terrestre calcul dans les axes satellite',13,'connaissant en entre:',13,'',13,'1 Le champ magntique en repre orbital (X Y Z )',13,'',13,'2  le vecteur d''tat  6 composantes (roulis  v_roulis tangage v_tangage lacet v_lacet)  ']],...
		'position',[300,230,301,231])

add_block('built-in/Note',[sys,'/',['Calcul champ magntique',13,'terrestre/ATTENTION:  Le schma utilise une fonction  utilisateur matlab -----> passage.m',13,' qui calcule la matrice de passage de la base satellite xyz  a la base orbitale XYZ']])
set_param([sys,'/',['Calcul champ magntique',13,'terrestre/ATTENTION:  Le schma utilise une fonction  utilisateur matlab -----> passage.m',13,' qui calcule la matrice de passage de la base satellite xyz  a la base orbitale XYZ']],...
		'ForeGround',2)
set_param([sys,'/',['Calcul champ magntique',13,'terrestre/ATTENTION:  Le schma utilise une fonction  utilisateur matlab -----> passage.m',13,' qui calcule la matrice de passage de la base satellite xyz  a la base orbitale XYZ']],...
		'Font Size',14)
set_param([sys,'/',['Calcul champ magntique',13,'terrestre/ATTENTION:  Le schma utilise une fonction  utilisateur matlab -----> passage.m',13,' qui calcule la matrice de passage de la base satellite xyz  a la base orbitale XYZ']],...
		'position',[300,335,301,336])
add_line([sys,'/',['Calcul champ magntique',13,'terrestre']],[90,90;210,90])
add_line([sys,'/',['Calcul champ magntique',13,'terrestre']],[90,135;120,135])
add_line([sys,'/',['Calcul champ magntique',13,'terrestre']],[190,135;210,135])
add_line([sys,'/',['Calcul champ magntique',13,'terrestre']],[260,115;290,115])
add_line([sys,'/',['Calcul champ magntique',13,'terrestre']],[405,115;435,115])
set_param([sys,'/',['Calcul champ magntique',13,'terrestre']],...
		'Mask Display','Calcul du champ\nmagntique terrestre\n(repre satellite)')


%     Finished composite block ['Calcul champ magntique',13,'terrestre'].

set_param([sys,'/',['Calcul champ magntique',13,'terrestre']],...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',10,...
		'position',[15,137,115,188])

add_block('built-in/Clock',[sys,'/','Clock'])
set_param([sys,'/','Clock'],...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',10,...
		'position',[20,215,40,235])

add_block('built-in/Sum',[sys,'/','Sum'])
set_param([sys,'/','Sum'],...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',10,...
		'position',[20,255,40,295])

add_block('built-in/Scope',[sys,'/','Scope'])
set_param([sys,'/','Scope'],...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',10,...
		'Vgain','0.150000',...
		'Hgain','80000.000000',...
		'Vmax','0.300000',...
		'Hmax','160000.000000',...
		'Window',[16,173,639,427])
set_param([sys,'/','Scope'],...
		'position',[75,249,115,291])

add_block('built-in/From File',[sys,'/','From File'])
set_param([sys,'/','From File'],...
		'position',[175,255,225,285])

add_block('built-in/Clock',[sys,'/','Clock1'])
set_param([sys,'/','Clock1'],...
		'position',[250,260,270,280])

add_block('built-in/Saturation',[sys,'/','Saturation'])
set_param([sys,'/','Saturation'],...
		'position',[300,260,325,280])

add_block('built-in/Switch',[sys,'/','Switch'])
set_param([sys,'/','Switch'],...
		'position',[100,314,125,346])

add_block('built-in/Transport Delay',[sys,'/','Transport Delay'])
set_param([sys,'/','Transport Delay'],...
		'Delay Time','1',...
		'position',[20,315,65,345])

add_block('built-in/MATLAB Fcn',[sys,'/','MATLAB Fcn'])
set_param([sys,'/','MATLAB Fcn'],...
		'position',[155,315,205,345])

add_block('built-in/To Workspace',[sys,'/','To Workspace1'])
set_param([sys,'/','To Workspace1'],...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',10,...
		'mat-name','sortie',...
		'buffer','points',...
		'position',[225,317,275,333])


%     Subsystem  ['Champ magntique',13,'calcul'].

new_system([sys,'/',['Champ magntique',13,'calcul']])
set_param([sys,'/',['Champ magntique',13,'calcul']],'Location',[0,38,624,464])

add_block('built-in/Constant',[sys,'/',['Champ magntique',13,'calcul/Constant3']])
set_param([sys,'/',['Champ magntique',13,'calcul/Constant3']],...
		'hide name',0,...
		'Value','rayon_orbital',...
		'position',[65,129,155,161])

add_block('built-in/Constant',[sys,'/',['Champ magntique',13,'calcul/Constant2']])
set_param([sys,'/',['Champ magntique',13,'calcul/Constant2']],...
		'hide name',0,...
		'Value','inclinaison',...
		'position',[65,89,155,121])

add_block('built-in/MATLAB Fcn',[sys,'/',['Champ magntique',13,'calcul/MATLAB Fcn']])
set_param([sys,'/',['Champ magntique',13,'calcul/MATLAB Fcn']],...
		'MATLAB Fcn','champmgn(u)',...
		'position',[270,77,395,133])

add_block('built-in/Clock',[sys,'/',['Champ magntique',13,'calcul/Clock']])
set_param([sys,'/',['Champ magntique',13,'calcul/Clock']],...
		'position',[65,55,85,75])

add_block('built-in/Mux',[sys,'/',['Champ magntique',13,'calcul/Mux']])
set_param([sys,'/',['Champ magntique',13,'calcul/Mux']],...
		'inputs','3',...
		'position',[210,48,250,162])

add_block('built-in/Note',[sys,'/',['Champ magntique',13,'calcul/Temps']])
set_param([sys,'/',['Champ magntique',13,'calcul/Temps']],...
		'position',[125,50,126,51])

add_block('built-in/Outport',[sys,'/',['Champ magntique',13,'calcul/out_1']])
set_param([sys,'/',['Champ magntique',13,'calcul/out_1']],...
		'position',[415,95,435,115])

add_block('built-in/Note',[sys,'/',['Champ magntique',13,'calcul/Nota bene:   Cette boite calcule le champ magntique en fonction du temps avec comme ',13,'convention que le temps 0 correspond au noeud ascendant de l''orbite. Si vous devez com',13,'mencer avec un dcalage, il faut ajouter ce dcalage  la premire entre.',13,'']])
set_param([sys,'/',['Champ magntique',13,'calcul/Nota bene:   Cette boite calcule le champ magntique en fonction du temps avec comme ',13,'convention que le temps 0 correspond au noeud ascendant de l''orbite. Si vous devez com',13,'mencer avec un dcalage, il faut ajouter ce dcalage  la premire entre.',13,'']],...
		'ForeGround',4)
set_param([sys,'/',['Champ magntique',13,'calcul/Nota bene:   Cette boite calcule le champ magntique en fonction du temps avec comme ',13,'convention que le temps 0 correspond au noeud ascendant de l''orbite. Si vous devez com',13,'mencer avec un dcalage, il faut ajouter ce dcalage  la premire entre.',13,'']],...
		'Font Size',12)
set_param([sys,'/',['Champ magntique',13,'calcul/Nota bene:   Cette boite calcule le champ magntique en fonction du temps avec comme ',13,'convention que le temps 0 correspond au noeud ascendant de l''orbite. Si vous devez com',13,'mencer avec un dcalage, il faut ajouter ce dcalage  la premire entre.',13,'']],...
		'position',[315,200,316,201])

add_block('built-in/Note',[sys,'/',['Champ magntique',13,'calcul/ATTENTION: Cette boite ncessite la fonction matlab  --------> champmagn.m',13,'et la donne dans l''espace de travail de l''inclinaison orbitale (en rd) et du rayon',13,'orbital (en km)']])
set_param([sys,'/',['Champ magntique',13,'calcul/ATTENTION: Cette boite ncessite la fonction matlab  --------> champmagn.m',13,'et la donne dans l''espace de travail de l''inclinaison orbitale (en rd) et du rayon',13,'orbital (en km)']],...
		'ForeGround',2)
set_param([sys,'/',['Champ magntique',13,'calcul/ATTENTION: Cette boite ncessite la fonction matlab  --------> champmagn.m',13,'et la donne dans l''espace de travail de l''inclinaison orbitale (en rd) et du rayon',13,'orbital (en km)']],...
		'Font Size',14)
set_param([sys,'/',['Champ magntique',13,'calcul/ATTENTION: Cette boite ncessite la fonction matlab  --------> champmagn.m',13,'et la donne dans l''espace de travail de l''inclinaison orbitale (en rd) et du rayon',13,'orbital (en km)']],...
		'position',[320,280,321,281])
add_line([sys,'/',['Champ magntique',13,'calcul']],[255,105;260,105])
add_line([sys,'/',['Champ magntique',13,'calcul']],[160,145;200,145])
add_line([sys,'/',['Champ magntique',13,'calcul']],[90,65;200,65])
add_line([sys,'/',['Champ magntique',13,'calcul']],[160,105;200,105])
add_line([sys,'/',['Champ magntique',13,'calcul']],[400,105;405,105])
set_param([sys,'/',['Champ magntique',13,'calcul']],...
		'Mask Display','CHAMP TERRESTRE\nEN REPERE ORBITAL')


%     Finished composite block ['Champ magntique',13,'calcul'].

set_param([sys,'/',['Champ magntique',13,'calcul']],...
		'position',[140,56,245,114])


%     Subsystem  'Saturation  3 voies'.

new_system([sys,'/','Saturation  3 voies'])
set_param([sys,'/','Saturation  3 voies'],'Location',[4,42,628,468])

add_block('built-in/Inport',[sys,'/','Saturation  3 voies/in_1'])
set_param([sys,'/','Saturation  3 voies/in_1'],...
		'position',[65,120,85,140])

add_block('built-in/Outport',[sys,'/','Saturation  3 voies/out_1'])
set_param([sys,'/','Saturation  3 voies/out_1'],...
		'position',[350,120,370,140])

add_block('built-in/Saturation',[sys,'/','Saturation  3 voies/Saturation'])
set_param([sys,'/','Saturation  3 voies/Saturation'],...
		'hide name',0,...
		'Lower Limit','[-0.5 -0.5 -0.5]',...
		'Upper Limit','[0.5 0.5 0.5]',...
		'position',[185,112,225,148])

add_block('built-in/Saturation',[sys,'/','Saturation  3 voies/Saturation1'])
set_param([sys,'/','Saturation  3 voies/Saturation1'],...
		'hide name',0,...
		'Lower Limit','[-0.5 -0.5 -0.5]',...
		'Upper Limit','[0.5 0.5 0.5]',...
		'position',[185,152,225,188])

add_block('built-in/Saturation',[sys,'/','Saturation  3 voies/Saturation2'])
set_param([sys,'/','Saturation  3 voies/Saturation2'],...
		'hide name',0,...
		'Lower Limit','[-0.2 -0.4 -0.1]',...
		'Upper Limit','[0.2 0.2 0.1]',...
		'position',[185,72,225,108])

add_block('built-in/Demux',[sys,'/','Saturation  3 voies/Demux'])
set_param([sys,'/','Saturation  3 voies/Demux'],...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',10,...
		'outputs','3',...
		'position',[115,69,150,191])

add_block('built-in/Mux',[sys,'/','Saturation  3 voies/Mux'])
set_param([sys,'/','Saturation  3 voies/Mux'],...
		'inputs','3',...
		'position',[285,71,320,189])

add_block('built-in/Note',[sys,'/','Saturation  3 voies/LES NIVEAUX DE SATURATION sur chaque voie doivent etre rgls '])
set_param([sys,'/','Saturation  3 voies/LES NIVEAUX DE SATURATION sur chaque voie doivent etre rgls '],...
		'ForeGround',4,...
		'Font Size',12,...
		'position',[255,250,256,251])
add_line([sys,'/','Saturation  3 voies'],[230,170;275,170])
add_line([sys,'/','Saturation  3 voies'],[230,130;275,130])
add_line([sys,'/','Saturation  3 voies'],[230,90;275,90])
add_line([sys,'/','Saturation  3 voies'],[155,170;175,170])
add_line([sys,'/','Saturation  3 voies'],[155,130;175,130])
add_line([sys,'/','Saturation  3 voies'],[155,90;175,90])
add_line([sys,'/','Saturation  3 voies'],[325,130;340,130])
add_line([sys,'/','Saturation  3 voies'],[90,130;105,130])
set_param([sys,'/','Saturation  3 voies'],...
		'Mask Display','SATURATION')


%     Finished composite block 'Saturation  3 voies'.

set_param([sys,'/','Saturation  3 voies'],...
		'position',[145,143,215,187])


%     Subsystem  ['Commande par moment ',13,'cintique'].

new_system([sys,'/',['Commande par moment ',13,'cintique']])
set_param([sys,'/',['Commande par moment ',13,'cintique']],'Location',[4,42,628,468])

add_block('built-in/Note',[sys,'/',['Commande par moment ',13,'cintique/Cette boite calcule (SANS GAIN):',13,'',13,' le couple de commande par magnetocoupleurs H ^ B connaissant en entre:',13,'',13,'1 Le champ magntique en axes satellite',13,'',13,'2  le vecteur d''tat  6 composantes (roulis  v_roulis tangage v_tangage lacet v_lacet) ']])
set_param([sys,'/',['Commande par moment ',13,'cintique/Cette boite calcule (SANS GAIN):',13,'',13,' le couple de commande par magnetocoupleurs H ^ B connaissant en entre:',13,'',13,'1 Le champ magntique en axes satellite',13,'',13,'2  le vecteur d''tat  6 composantes (roulis  v_roulis tangage v_tangage lacet v_lacet) ']],...
		'ForeGround',4)
set_param([sys,'/',['Commande par moment ',13,'cintique/Cette boite calcule (SANS GAIN):',13,'',13,' le couple de commande par magnetocoupleurs H ^ B connaissant en entre:',13,'',13,'1 Le champ magntique en axes satellite',13,'',13,'2  le vecteur d''tat  6 composantes (roulis  v_roulis tangage v_tangage lacet v_lacet) ']],...
		'Font Size',12)
set_param([sys,'/',['Commande par moment ',13,'cintique/Cette boite calcule (SANS GAIN):',13,'',13,' le couple de commande par magnetocoupleurs H ^ B connaissant en entre:',13,'',13,'1 Le champ magntique en axes satellite',13,'',13,'2  le vecteur d''tat  6 composantes (roulis  v_roulis tangage v_tangage lacet v_lacet) ']],...
		'position',[360,225,361,226])

add_block('built-in/Mux',[sys,'/',['Commande par moment ',13,'cintique/Mux4']])
set_param([sys,'/',['Commande par moment ',13,'cintique/Mux4']],...
		'hide name',0,...
		'inputs','[3 3]',...
		'position',[295,65,330,160])

add_block('built-in/MATLAB Fcn',[sys,'/',['Commande par moment ',13,'cintique/MATLAB Fcn']])
set_param([sys,'/',['Commande par moment ',13,'cintique/MATLAB Fcn']],...
		'hide name',0,...
		'MATLAB Fcn','cross(u(1:3),u(4:6))',...
		'Output Width','3',...
		'Mask Display','MOMENT MAGNETIQUE\nH x B en axes satellite')
set_param([sys,'/',['Commande par moment ',13,'cintique/MATLAB Fcn']],...
		'position',[355,91,465,139])

add_block('built-in/State-space',[sys,'/',['Commande par moment ',13,'cintique/Matrix gain.4']])
set_param([sys,'/',['Commande par moment ',13,'cintique/Matrix gain.4']],...
		'hide name',0,...
		'A','[]',...
		'B','[]',...
		'C','[]',...
		'D','K',...
		'Mask Display','Moment cinetique\nrsiduel',...
		'Mask Type','Matrix gain')
set_param([sys,'/',['Commande par moment ',13,'cintique/Matrix gain.4']],...
		'Mask Dialogue','Matrix Gain:|Gain matrix:',...
		'Mask Translate','K = @1;',...
		'Mask Help','Multiplies input vector by entered matrix to produce output vector.')
set_param([sys,'/',['Commande par moment ',13,'cintique/Matrix gain.4']],...
		'Mask Entries','[0 Ir 0 0 0 0;0 0 0 It 0 0 ;0 0 0 0 0 10*Il]\/',...
		'position',[195,116,270,154])

add_block('built-in/Note',[sys,'/',['Commande par moment ',13,'cintique/Vecteur',13,'d''tat']])
set_param([sys,'/',['Commande par moment ',13,'cintique/Vecteur',13,'d''tat']],...
		'position',[168,105,169,106])

add_block('built-in/Note',[sys,'/',['Commande par moment ',13,'cintique/Champ magntique',13,'terrestre',13,'(repre orbital)']])
set_param([sys,'/',['Commande par moment ',13,'cintique/Champ magntique',13,'terrestre',13,'(repre orbital)']],...
		'position',[215,50,216,51])

add_block('built-in/Inport',[sys,'/',['Commande par moment ',13,'cintique/in_1']])
set_param([sys,'/',['Commande par moment ',13,'cintique/in_1']],...
		'position',[120,80,140,100])

add_block('built-in/Outport',[sys,'/',['Commande par moment ',13,'cintique/out_1']])
set_param([sys,'/',['Commande par moment ',13,'cintique/out_1']],...
		'position',[485,105,505,125])

add_block('built-in/Inport',[sys,'/',['Commande par moment ',13,'cintique/in_2']])
set_param([sys,'/',['Commande par moment ',13,'cintique/in_2']],...
		'Port','2',...
		'position',[120,125,140,145])
add_line([sys,'/',['Commande par moment ',13,'cintique']],[335,115;345,115])
add_line([sys,'/',['Commande par moment ',13,'cintique']],[275,135;285,135])
add_line([sys,'/',['Commande par moment ',13,'cintique']],[145,90;285,90])
add_line([sys,'/',['Commande par moment ',13,'cintique']],[470,115;475,115])
add_line([sys,'/',['Commande par moment ',13,'cintique']],[145,135;185,135])
set_param([sys,'/',['Commande par moment ',13,'cintique']],...
		'Mask Display','COMMANDE PAR LE\nMOMENT CINETIQUE\nRESIDUEL')


%     Finished composite block ['Commande par moment ',13,'cintique'].

set_param([sys,'/',['Commande par moment ',13,'cintique']],...
		'position',[270,62,375,113])

add_block('built-in/State-space',[sys,'/',['Modle de la dynamique',13,'satellite']])
set_param([sys,'/',['Modle de la dynamique',13,'satellite']],...
		'Font Name','Arial',...
		'Font Size',10,...
		'A','Asat',...
		'B','Bsat',...
		'C','eye(Asat)',...
		'D','zeros(Bsat)',...
		'X0','[0.1 0 0.1 0 0.05 -0.001]''')
set_param([sys,'/',['Modle de la dynamique',13,'satellite']],...
		'position',[255,133,365,177])


%     Subsystem  ['Vecteur constant',13,'3 composantes'].

new_system([sys,'/',['Vecteur constant',13,'3 composantes']])
set_param([sys,'/',['Vecteur constant',13,'3 composantes']],'Location',[130,213,380,388])

add_block('built-in/Mux',[sys,'/',['Vecteur constant',13,'3 composantes/Mux']])
set_param([sys,'/',['Vecteur constant',13,'3 composantes/Mux']],...
		'inputs','3',...
		'position',[160,52,190,128])

add_block('built-in/Constant',[sys,'/',['Vecteur constant',13,'3 composantes/Constant1']])
set_param([sys,'/',['Vecteur constant',13,'3 composantes/Constant1']],...
		'hide name',0,...
		'Value','0',...
		'position',[50,55,95,75])

add_block('built-in/Constant',[sys,'/',['Vecteur constant',13,'3 composantes/Constant2']])
set_param([sys,'/',['Vecteur constant',13,'3 composantes/Constant2']],...
		'hide name',0,...
		'Value','8e-6',...
		'position',[50,80,95,100])

add_block('built-in/Constant',[sys,'/',['Vecteur constant',13,'3 composantes/Constant3']])
set_param([sys,'/',['Vecteur constant',13,'3 composantes/Constant3']],...
		'hide name',0,...
		'Value','0',...
		'position',[50,105,95,125])

add_block('built-in/Outport',[sys,'/',['Vecteur constant',13,'3 composantes/out_1']])
set_param([sys,'/',['Vecteur constant',13,'3 composantes/out_1']],...
		'position',[235,80,255,100])
add_line([sys,'/',['Vecteur constant',13,'3 composantes']],[100,115;150,115])
add_line([sys,'/',['Vecteur constant',13,'3 composantes']],[100,90;150,90])
add_line([sys,'/',['Vecteur constant',13,'3 composantes']],[100,65;150,65])
add_line([sys,'/',['Vecteur constant',13,'3 composantes']],[195,90;225,90])
set_param([sys,'/',['Vecteur constant',13,'3 composantes']],...
		'Mask Display','Vecteur\nconstant')


%     Finished composite block ['Vecteur constant',13,'3 composantes'].

set_param([sys,'/',['Vecteur constant',13,'3 composantes']],...
		'position',[390,72,475,108])

add_block('built-in/To Workspace',[sys,'/','To Workspace'])
set_param([sys,'/','To Workspace'],...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',10,...
		'mat-name','temps',...
		'buffer','points_trace',...
		'position',[60,217,110,233])

add_block('built-in/Discrete State-space',[sys,'/','Dis. State-space'])
set_param([sys,'/','Dis. State-space'],...
		'position',[20,370,115,410])

add_block('built-in/Constant',[sys,'/','Constant'])
set_param([sys,'/','Constant'],...
		'position',[135,260,155,280])

add_block('built-in/Product',[sys,'/','Product'])
set_param([sys,'/','Product'],...
		'position',[305,305,330,325])

add_block('built-in/Inport',[sys,'/','Inport'])
set_param([sys,'/','Inport'],...
		'position',[435,290,455,310])

add_block('built-in/Outport',[sys,'/','Outport'])
set_param([sys,'/','Outport'],...
		'position',[435,330,455,350])

add_block('built-in/To File',[sys,'/','To File'])
set_param([sys,'/','To File'],...
		'orientation',2,...
		'Font Size',10,...
		'File name','nom_fich.mat',...
		'Matrix name','nom_var',...
		'position',[225,367,325,403])

add_block('built-in/Derivative',[sys,'/','Derivative'])
set_param([sys,'/','Derivative'],...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',10,...
		'position',[125,210,180,240])

add_block('built-in/Integrator',[sys,'/','Integrator'])
set_param([sys,'/','Integrator'],...
		'hide name',0,...
		'position',[215,210,270,240])

add_block('built-in/Mux',[sys,'/','Mux'])
set_param([sys,'/','Mux'],...
		'hide name',0,...
		'inputs','[3 6]',...
		'position',[285,204,320,251])

add_block('built-in/Demux',[sys,'/','Demux'])
set_param([sys,'/','Demux'],...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',10,...
		'outputs','3',...
		'position',[345,207,385,253])


%     Subsystem  'Vecteur bruit'.

new_system([sys,'/','Vecteur bruit'])
set_param([sys,'/','Vecteur bruit'],'Location',[4,95,509,460])

add_block('built-in/Demux',[sys,'/','Vecteur bruit/Demux'])
set_param([sys,'/','Vecteur bruit/Demux'],...
		'outputs','3',...
		'position',[105,81,160,339])

add_block('built-in/Product',[sys,'/','Vecteur bruit/Product'])
set_param([sys,'/','Vecteur bruit/Product'],...
		'position',[305,120,330,140])

add_block('built-in/Product',[sys,'/','Vecteur bruit/Product3'])
set_param([sys,'/','Vecteur bruit/Product3'],...
		'position',[305,280,330,300])

add_block('built-in/Mux',[sys,'/','Vecteur bruit/Mux'])
set_param([sys,'/','Vecteur bruit/Mux'],...
		'inputs','3',...
		'position',[395,90,425,330])

add_block('built-in/Product',[sys,'/','Vecteur bruit/Product1'])
set_param([sys,'/','Vecteur bruit/Product1'],...
		'position',[305,195,330,215])


%     Subsystem  ['Vecteur bruit/Bruit de mesure',13,'(coeff_bruit)'].

new_system([sys,'/',['Vecteur bruit/Bruit de mesure',13,'(coeff_bruit)']])
set_param([sys,'/',['Vecteur bruit/Bruit de mesure',13,'(coeff_bruit)']],'Location',[4,127,239,312])

add_block('built-in/White Noise',[sys,'/',['Vecteur bruit/Bruit de mesure',13,'(coeff_bruit)/White Noise']])
set_param([sys,'/',['Vecteur bruit/Bruit de mesure',13,'(coeff_bruit)/White Noise']],...
		'position',[80,65,100,85])

add_block('built-in/Constant',[sys,'/',['Vecteur bruit/Bruit de mesure',13,'(coeff_bruit)/Constant']])
set_param([sys,'/',['Vecteur bruit/Bruit de mesure',13,'(coeff_bruit)/Constant']],...
		'Value','coeff_bruit',...
		'position',[45,105,115,135])

add_block('built-in/Product',[sys,'/',['Vecteur bruit/Bruit de mesure',13,'(coeff_bruit)/Product']])
set_param([sys,'/',['Vecteur bruit/Bruit de mesure',13,'(coeff_bruit)/Product']],...
		'position',[140,54,170,141])

add_block('built-in/Outport',[sys,'/',['Vecteur bruit/Bruit de mesure',13,'(coeff_bruit)/out_1']])
set_param([sys,'/',['Vecteur bruit/Bruit de mesure',13,'(coeff_bruit)/out_1']],...
		'position',[200,90,220,110])
add_line([sys,'/',['Vecteur bruit/Bruit de mesure',13,'(coeff_bruit)']],[120,120;130,120])
add_line([sys,'/',['Vecteur bruit/Bruit de mesure',13,'(coeff_bruit)']],[105,75;130,75])
add_line([sys,'/',['Vecteur bruit/Bruit de mesure',13,'(coeff_bruit)']],[175,100;190,100])
set_param([sys,'/',['Vecteur bruit/Bruit de mesure',13,'(coeff_bruit)']],...
		'Mask Display','BRUIT')


%     Finished composite block ['Vecteur bruit/Bruit de mesure',13,'(coeff_bruit)'].

set_param([sys,'/',['Vecteur bruit/Bruit de mesure',13,'(coeff_bruit)']],...
		'position',[180,60,255,100])

add_block('built-in/Inport',[sys,'/','Vecteur bruit/in_1'])
set_param([sys,'/','Vecteur bruit/in_1'],...
		'position',[55,200,75,220])

add_block('built-in/Outport',[sys,'/','Vecteur bruit/out_1'])
set_param([sys,'/','Vecteur bruit/out_1'],...
		'position',[455,200,475,220])
add_line([sys,'/','Vecteur bruit'],[335,130;385,130])
add_line([sys,'/','Vecteur bruit'],[335,205;385,210])
add_line([sys,'/','Vecteur bruit'],[335,290;385,290])
add_line([sys,'/','Vecteur bruit'],[260,80;280,80;280,135;295,135])
add_line([sys,'/','Vecteur bruit'],[280,135;280,200;295,200])
add_line([sys,'/','Vecteur bruit'],[280,200;280,285;295,285])
add_line([sys,'/','Vecteur bruit'],[165,295;295,295])
add_line([sys,'/','Vecteur bruit'],[165,210;295,210])
add_line([sys,'/','Vecteur bruit'],[165,125;295,125])
add_line([sys,'/','Vecteur bruit'],[80,210;95,210])
add_line([sys,'/','Vecteur bruit'],[430,210;445,210])
set_param([sys,'/','Vecteur bruit'],...
		'Mask Display','VECTEUR BRUITE\nj(Coeff_bruit)')


%     Finished composite block 'Vecteur bruit'.

set_param([sys,'/','Vecteur bruit'],...
		'position',[405,207,500,253])


%     Subsystem  'Sortie 6 voies'.

new_system([sys,'/','Sortie 6 voies'])
set_param([sys,'/','Sortie 6 voies'],'Location',[310,215,565,460])

add_block('built-in/To Workspace',[sys,'/','Sortie 6 voies/To Workspace7'])
set_param([sys,'/','Sortie 6 voies/To Workspace7'],...
		'hide name',0,...
		'mat-name','v_lacet',...
		'buffer','points_trace',...
		'position',[160,192,210,208])

add_block('built-in/To Workspace',[sys,'/','Sortie 6 voies/To Workspace6'])
set_param([sys,'/','Sortie 6 voies/To Workspace6'],...
		'hide name',0,...
		'mat-name','lacet',...
		'buffer','points_trace',...
		'position',[160,167,210,183])

add_block('built-in/To Workspace',[sys,'/','Sortie 6 voies/To Workspace5'])
set_param([sys,'/','Sortie 6 voies/To Workspace5'],...
		'hide name',0,...
		'mat-name','v_tangage',...
		'buffer','points_trace',...
		'position',[160,142,210,158])

add_block('built-in/To Workspace',[sys,'/','Sortie 6 voies/To Workspace4'])
set_param([sys,'/','Sortie 6 voies/To Workspace4'],...
		'hide name',0,...
		'mat-name','tangage',...
		'buffer','points_trace',...
		'position',[160,117,210,133])

add_block('built-in/To Workspace',[sys,'/','Sortie 6 voies/To Workspace3'])
set_param([sys,'/','Sortie 6 voies/To Workspace3'],...
		'hide name',0,...
		'mat-name','v_roulis',...
		'buffer','points_trace',...
		'position',[160,92,210,108])

add_block('built-in/Demux',[sys,'/','Sortie 6 voies/Demux1'])
set_param([sys,'/','Sortie 6 voies/Demux1'],...
		'hide name',0,...
		'outputs','6',...
		'position',[60,59,100,216])

add_block('built-in/To Workspace',[sys,'/','Sortie 6 voies/To Workspace2'])
set_param([sys,'/','Sortie 6 voies/To Workspace2'],...
		'hide name',0,...
		'mat-name','roulis',...
		'buffer','points_trace',...
		'position',[160,67,210,83])

add_block('built-in/Inport',[sys,'/','Sortie 6 voies/in_2'])
set_param([sys,'/','Sortie 6 voies/in_2'],...
		'Port','2',...
		'position',[10,130,30,150])
add_line([sys,'/','Sortie 6 voies'],[105,200;150,200])
add_line([sys,'/','Sortie 6 voies'],[105,175;150,175])
add_line([sys,'/','Sortie 6 voies'],[105,150;150,150])
add_line([sys,'/','Sortie 6 voies'],[105,125;150,125])
add_line([sys,'/','Sortie 6 voies'],[105,100;150,100])
add_line([sys,'/','Sortie 6 voies'],[105,75;150,75])
add_line([sys,'/','Sortie 6 voies'],[35,140;50,140])
set_param([sys,'/','Sortie 6 voies'],...
		'Mask Display','SORTIE FICHIER\n6 VOIES')


%     Finished composite block 'Sortie 6 voies'.

set_param([sys,'/','Sortie 6 voies'],...
		'position',[385,132,470,178])

add_block('built-in/Unit Delay',[sys,'/','Unit Delay'])
set_param([sys,'/','Unit Delay'],...
		'position',[145,382,195,398])


%     Subsystem  'UnNamed1'.

new_system([sys,'/','UnNamed1'])
set_param([sys,'/','UnNamed1'],'Location',[10,80,320,360])

add_block('built-in/Inport',[sys,'/','UnNamed1/in_1'])
set_param([sys,'/','UnNamed1/in_1'],...
		'position',[25,135,45,155])

add_block('built-in/Outport',[sys,'/','UnNamed1/out_1'])
set_param([sys,'/','UnNamed1/out_1'],...
		'position',[275,135,295,155])

add_block('built-in/Demux',[sys,'/','UnNamed1/Demux2'])
set_param([sys,'/','UnNamed1/Demux2'],...
		'BackGround',3,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',10,...
		'outputs','3',...
		'position',[75,64,95,226])

add_block('built-in/Transfer Fcn',[sys,'/','UnNamed1/Transfer Fcn'])
set_param([sys,'/','UnNamed1/Transfer Fcn'],...
		'Numerator','[1 0]',...
		'Denominator','[0.2 1]',...
		'position',[135,72,170,108])

add_block('built-in/Transfer Fcn',[sys,'/','UnNamed1/Transfer Fcn1'])
set_param([sys,'/','UnNamed1/Transfer Fcn1'],...
		'Numerator','[1 0]',...
		'Denominator','[0.2 1]',...
		'position',[135,127,170,163])

add_block('built-in/Transfer Fcn',[sys,'/','UnNamed1/Transfer Fcn2'])
set_param([sys,'/','UnNamed1/Transfer Fcn2'],...
		'Numerator','[1 0]',...
		'Denominator','[0.1 1]',...
		'position',[135,182,170,218])

add_block('built-in/Mux',[sys,'/','UnNamed1/Mux'])
set_param([sys,'/','UnNamed1/Mux'],...
		'BackGround',3,...
		'inputs','3',...
		'position',[220,63,245,227])
add_line([sys,'/','UnNamed1'],[50,145;65,145])
add_line([sys,'/','UnNamed1'],[250,145;265,145])
add_line([sys,'/','UnNamed1'],[100,90;125,90])
add_line([sys,'/','UnNamed1'],[100,145;125,145])
add_line([sys,'/','UnNamed1'],[100,200;125,200])
add_line([sys,'/','UnNamed1'],[175,200;210,200])
add_line([sys,'/','UnNamed1'],[175,145;210,145])
add_line([sys,'/','UnNamed1'],[175,90;210,90])
set_param([sys,'/','UnNamed1'],...
		'Mask Display','DERIVEE')


%     Finished composite block 'UnNamed1'.

set_param([sys,'/','UnNamed1'],...
		'orientation',2,...
		'position',[370,371,435,409])
add_line(sys,[45,225;50,225])

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str] = feval(sys);
	end
end
