function [ret,x0,str]=scaoder2(t,x,u,flag);
%SCAODER2	is the M-file description of the SIMULINK system named SCAODER2.
%	The block-diagram can be displayed by typing: SCAODER2.
%
%	SYS=SCAODER2(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes SCAODER2 to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling SCAODER2 with a FLAG of zero:
%	[SIZES]=SCAODER2([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs.
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.2)
if(0 == (nargin + nargout))
     set_param(sys,'Location',[4,42,628,468])
     open_system(sys)
end;
set_param(sys,'BackGround',0)
set_param(sys,'algorithm',		'Linear')
set_param(sys,'Start time',	'0.0')
set_param(sys,'Stop time',		'tsim')
set_param(sys,'Min step size',	'tsim/4000')
set_param(sys,'Max step size',	'tsim/1000')
set_param(sys,'Relative error','1e-3')
set_param(sys,'Return vars',	'')

add_block('built-in/Sum',[sys,'/','Sum'])
set_param([sys,'/','Sum'],...
		'BackGround',2,...
		'hide name',0,...
		'inputs','++-',...
		'position',[120,128,145,252])

add_block('built-in/Scope',[sys,'/','Scope'])
set_param([sys,'/','Scope'],...
		'BackGround',5,...
		'hide name',0,...
		'Vgain','0.150000',...
		'Hgain','40000.000000',...
		'Vmax','0.300000',...
		'Hmax','80000.000000',...
		'Window',[7,51,607,307])
open_system([sys,'/','Scope'])
set_param([sys,'/','Scope'],...
		'position',[515,108,560,152])

add_block('built-in/Integrator',[sys,'/','Integrator'])
set_param([sys,'/','Integrator'],...
		'BackGround',2,...
		'hide name',0,...
		'position',[215,175,270,205])

add_block('built-in/Gain',[sys,'/','Gain3'])
set_param([sys,'/','Gain3'],...
		'BackGround',6,...
		'hide name',0,...
		'Gain','1/It',...
		'position',[165,170,195,210])

add_block('built-in/Integrator',[sys,'/','Integrator1'])
set_param([sys,'/','Integrator1'],...
		'BackGround',2,...
		'hide name',0,...
		'Initial','0.1',...
		'position',[295,176,360,204])

add_block('built-in/Product',[sys,'/','Product1'])
set_param([sys,'/','Product1'],...
		'orientation',2,...
		'BackGround',7,...
		'hide name',0,...
		'position',[155,90,185,145])

add_block('built-in/Constant',[sys,'/','Constant1'])
set_param([sys,'/','Constant1'],...
		'orientation',2,...
		'BackGround',7,...
		'hide name',0,...
		'Value','-3*vitesse_rotation^2*(Ir-Il)',...
		'position',[230,91,365,119])

add_block('built-in/To Workspace',[sys,'/','To Workspace'])
set_param([sys,'/','To Workspace'],...
		'ForeGround',3,...
		'BackGround',6,...
		'hide name',0,...
		'mat-name','temps',...
		'buffer','points_trace',...
		'position',[510,77,560,93])

add_block('built-in/Clock',[sys,'/','Clock'])
set_param([sys,'/','Clock'],...
		'ForeGround',3,...
		'BackGround',6,...
		'hide name',0,...
		'position',[445,75,465,95])

add_block('built-in/From Workspace',[sys,'/','From Workspace'])
set_param([sys,'/','From Workspace'],...
		'orientation',2,...
		'hide name',0,...
		'matl_expr','[champ_magn_terr]',...
		'Mask Display','Champ magntique\nterrestre\n(repre orbital)',...
		'position',[475,256,580,314])

add_block('built-in/Note',[sys,'/','Dynamique satellite'])
set_param([sys,'/','Dynamique satellite'],...
		'ForeGround',2,...
		'Font Size',14,...
		'position',[285,150,286,151])

add_block('built-in/Gain',[sys,'/','Gain2'])
set_param([sys,'/','Gain2'],...
		'BackGround',6,...
		'hide name',0,...
		'position',[70,170,100,210])

add_block('built-in/Constant',[sys,'/','Constant2'])
set_param([sys,'/','Constant2'],...
		'BackGround',7,...
		'hide name',0,...
		'Value','8e-6',...
		'position',[20,175,55,205])

add_block('built-in/To Workspace',[sys,'/','To Workspace1'])
set_param([sys,'/','To Workspace1'],...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','tangage',...
		'buffer','points_trace',...
		'position',[510,182,560,198])

add_block('built-in/Note',[sys,'/','Rappel gradient'])
set_param([sys,'/','Rappel gradient'],...
		'ForeGround',7,...
		'position',[290,70,291,71])


%     Subsystem  'UnNamed'.

new_system([sys,'/','UnNamed'])
set_param([sys,'/','UnNamed'],'Location',[25,95,581,440])

add_block('built-in/Product',[sys,'/','UnNamed/Product4'])
set_param([sys,'/','UnNamed/Product4'],...
		'position',[380,120,405,140])

add_block('built-in/Gain',[sys,'/','UnNamed/Gain'])
set_param([sys,'/','UnNamed/Gain'],...
		'Gain','0',...
		'position',[185,200,205,220])

add_block('built-in/Note',[sys,'/','UnNamed/Bz'])
set_param([sys,'/','UnNamed/Bz'],...
		'position',[310,260,311,261])

add_block('built-in/Sum',[sys,'/','UnNamed/Sum1'])
set_param([sys,'/','UnNamed/Sum1'],...
		'position',[265,239,290,306])

add_block('built-in/Product',[sys,'/','UnNamed/Product3'])
set_param([sys,'/','UnNamed/Product3'],...
		'position',[205,280,230,300])

add_block('built-in/Product',[sys,'/','UnNamed/Product2'])
set_param([sys,'/','UnNamed/Product2'],...
		'position',[205,245,230,265])

add_block('built-in/Note',[sys,'/','UnNamed/Bx'])
set_param([sys,'/','UnNamed/Bx'],...
		'position',[305,100,306,101])

add_block('built-in/Sum',[sys,'/','UnNamed/Sum'])
set_param([sys,'/','UnNamed/Sum'],...
		'inputs','+-+',...
		'position',[260,90,285,160])

add_block('built-in/Product',[sys,'/','UnNamed/Product1'])
set_param([sys,'/','UnNamed/Product1'],...
		'position',[200,125,225,145])

add_block('built-in/Product',[sys,'/','UnNamed/Product'])
set_param([sys,'/','UnNamed/Product'],...
		'position',[200,90,225,110])

add_block('built-in/MATLAB Fcn',[sys,'/','UnNamed/MATLAB Fcn1'])
set_param([sys,'/','UnNamed/MATLAB Fcn1'],...
		'hide name',0,...
		'MATLAB Fcn','cos(u)',...
		'Mask Display','cos(teta)',...
		'position',[85,80,135,110])

add_block('built-in/MATLAB Fcn',[sys,'/','UnNamed/MATLAB Fcn'])
set_param([sys,'/','UnNamed/MATLAB Fcn'],...
		'hide name',0,...
		'MATLAB Fcn','sin(u)',...
		'Mask Display','sin(teta)',...
		'position',[85,115,135,145])

add_block('built-in/Derivative',[sys,'/','UnNamed/Derivative'])
set_param([sys,'/','UnNamed/Derivative'],...
		'position',[315,140,345,160])

add_block('built-in/Derivative',[sys,'/','UnNamed/Derivative1'])
set_param([sys,'/','UnNamed/Derivative1'],...
		'position',[310,220,340,240])

add_block('built-in/Product',[sys,'/','UnNamed/Product5'])
set_param([sys,'/','UnNamed/Product5'],...
		'position',[385,260,410,280])

add_block('built-in/Sum',[sys,'/','UnNamed/Sum2'])
set_param([sys,'/','UnNamed/Sum2'],...
		'inputs','+-',...
		'position',[440,159,465,226])

add_block('built-in/Demux',[sys,'/','UnNamed/Demux'])
set_param([sys,'/','UnNamed/Demux'],...
		'outputs','3',...
		'position',[60,194,100,226])

add_block('built-in/Outport',[sys,'/','UnNamed/out_1'])
set_param([sys,'/','UnNamed/out_1'],...
		'position',[480,185,500,205])

add_block('built-in/Inport',[sys,'/','UnNamed/in_2'])
set_param([sys,'/','UnNamed/in_2'],...
		'Port','2',...
		'position',[10,200,30,220])

add_block('built-in/Inport',[sys,'/','UnNamed/in_1'])
set_param([sys,'/','UnNamed/in_1'],...
		'position',[10,120,30,140])

add_block('built-in/Note',[sys,'/',['UnNamed/Angle',13,'teta']])
set_param([sys,'/',['UnNamed/Angle',13,'teta']],...
		'position',[45,65,46,66])

add_block('built-in/Note',[sys,'/',['UnNamed/Changement d''axes']])
set_param([sys,'/',['UnNamed/Changement d''axes']],...
		'position',[185,60,186,61])

add_block('built-in/Note',[sys,'/','UnNamed/Produit vectoriel en repre orbital'])
set_param([sys,'/','UnNamed/Produit vectoriel en repre orbital'],...
		'position',[345,65,346,66])

add_block('built-in/Note',[sys,'/',['UnNamed/Calcul de b''^b dans les axes satellite']])
set_param([sys,'/',['UnNamed/Calcul de b''^b dans les axes satellite']],...
		'Font Size',22,...
		'position',[290,15,291,16])

add_block('built-in/Note',[sys,'/','UnNamed/repre orbital'])
set_param([sys,'/','UnNamed/repre orbital'],...
		'position',[75,175,76,176])

add_block('built-in/Note',[sys,'/','UnNamed/vecteur B'])
set_param([sys,'/','UnNamed/vecteur B'],...
		'position',[75,160,76,161])
add_line([sys,'/','UnNamed'],[210,210;240,210;240,150;250,150])
add_line([sys,'/','UnNamed'],[105,210;175,210])
add_line([sys,'/','UnNamed'],[140,95;190,95])
add_line([sys,'/','UnNamed'],[105,200;155,200;155,105;190,105])
add_line([sys,'/','UnNamed'],[140,130;190,130])
add_line([sys,'/','UnNamed'],[105,220;170,220;170,140;190,140])
add_line([sys,'/','UnNamed'],[230,100;250,100])
add_line([sys,'/','UnNamed'],[230,135;250,125])
add_line([sys,'/','UnNamed'],[235,255;255,255])
add_line([sys,'/','UnNamed'],[235,290;255,290])
add_line([sys,'/','UnNamed'],[155,200;155,285;195,285])
add_line([sys,'/','UnNamed'],[160,130;160,295;195,295])
add_line([sys,'/','UnNamed'],[170,220;170,250;195,250])
add_line([sys,'/','UnNamed'],[140,95;140,260;195,260])
add_line([sys,'/','UnNamed'],[290,125;370,125])
add_line([sys,'/','UnNamed'],[295,275;375,275])
add_line([sys,'/','UnNamed'],[290,125;290,150;305,150])
add_line([sys,'/','UnNamed'],[295,275;295,230;300,230])
add_line([sys,'/','UnNamed'],[345,230;360,230;360,135;370,135])
add_line([sys,'/','UnNamed'],[350,150;365,150;365,265;375,265])
add_line([sys,'/','UnNamed'],[410,130;420,130;420,175;430,175])
add_line([sys,'/','UnNamed'],[415,270;425,270;425,210;430,210])
add_line([sys,'/','UnNamed'],[35,130;75,130])
add_line([sys,'/','UnNamed'],[35,130;35,95;75,95])
add_line([sys,'/','UnNamed'],[470,195;470,195])
add_line([sys,'/','UnNamed'],[35,210;50,210])
set_param([sys,'/','UnNamed'],...
		'Mask Display','CALCUL B'' ^ B')


%     Finished composite block 'UnNamed'.

set_param([sys,'/','UnNamed'],...
		'orientation',2,...
		'BackGround',3,...
		'hide name',0,...
		'position',[325,257,420,293])

add_block('built-in/Note',[sys,'/','GAIN A REGLER'])
set_param([sys,'/','GAIN A REGLER'],...
		'BackGround',6,...
		'Font Size',14,...
		'position',[230,230,231,231])

add_block('built-in/Note',[sys,'/','COMMANDE PAR DERIVEE'])
set_param([sys,'/','COMMANDE PAR DERIVEE'],...
		'ForeGround',3,...
		'Font Size',12,...
		'position',[375,305,376,306])

add_block('built-in/Note',[sys,'/','Perturbation'])
set_param([sys,'/','Perturbation'],...
		'ForeGround',7,...
		'position',[40,155,41,156])

add_block('built-in/Note',[sys,'/','INITIALISER avant par : SCAODAT2'])
set_param([sys,'/','INITIALISER avant par : SCAODAT2'],...
		'ForeGround',2,...
		'Font Size',12,...
		'position',[180,350,181,351])

add_block('built-in/Note',[sys,'/',['ou',13,'',13,'LOAD INITIAT']])
set_param([sys,'/',['ou',13,'',13,'LOAD INITIAT']],...
		'ForeGround',2,...
		'Font Size',12,...
		'position',[165,370,166,371])

add_block('built-in/Note',[sys,'/',['SIMULATION UNIAXE TANGAGE D''UN SCAO AVEC DERIVEE DU CHAMP']])
set_param([sys,'/',['SIMULATION UNIAXE TANGAGE D''UN SCAO AVEC DERIVEE DU CHAMP']],...
		'ForeGround',5,...
		'Font Size',14,...
		'position',[320,20,321,21])

add_block('built-in/To Workspace',[sys,'/','To Workspace2'])
set_param([sys,'/','To Workspace2'],...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','v_tangage',...
		'buffer','points_trace',...
		'position',[510,217,560,233])

add_block('built-in/Gain',[sys,'/','Gain'])
set_param([sys,'/','Gain'],...
		'orientation',2,...
		'BackGround',6,...
		'hide name',0,...
		'Gain','1e7',...
		'position',[255,255,285,295])

add_block('built-in/To Workspace',[sys,'/','To Workspace3'])
set_param([sys,'/','To Workspace3'],...
		'orientation',2,...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','commande_y',...
		'buffer','points_trace',...
		'position',[85,291,170,309])
add_line(sys,[275,190;285,190])
add_line(sys,[365,190;500,190])
add_line(sys,[320,275;295,275])
add_line(sys,[375,190;375,130;195,130])
add_line(sys,[225,105;195,105])
add_line(sys,[150,120;85,120;85,150;110,150])
add_line(sys,[470,85;500,85])
add_line(sys,[465,190;465,265;430,265])
add_line(sys,[470,285;430,285])
add_line(sys,[60,190;60,190])
add_line(sys,[105,190;110,190])
add_line(sys,[200,190;205,190])
add_line(sys,[150,190;155,190])
add_line(sys,[250,275;80,275;80,230;110,230])
add_line(sys,[375,130;505,130])
add_line(sys,[275,190;275,225;500,225])
add_line(sys,[215,275;215,300;180,300])

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str] = feval(sys);
	end
end
