function [ret,x0,str]=scaodera(t,x,u,flag);
%SCAODERA	is the M-file description of the SIMULINK system named SCAODERA.
%	The block-diagram can be displayed by typing: SCAODERA.
%
%	SYS=SCAODERA(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes SCAODERA to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling SCAODERA with a FLAG of zero:
%	[SIZES]=SCAODERA([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs.
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.2)
if(0 == (nargin + nargout))
     set_param(sys,'Location',[4,42,628,468])
     open_system(sys)
end;
set_param(sys,'BackGround',0)
set_param(sys,'algorithm',		'Linear')
set_param(sys,'Start time',	'0.0')
set_param(sys,'Stop time',		'tsim')
set_param(sys,'Min step size',	'tsim/4000')
set_param(sys,'Max step size',	'tsim/4000')
set_param(sys,'Relative error','1e-3')
set_param(sys,'Return vars',	'')

add_block('built-in/Constant',[sys,'/','Constant2'])
set_param([sys,'/','Constant2'],...
		'BackGround',7,...
		'hide name',0,...
		'Value','5e-6',...
		'position',[25,145,60,175])

add_block('built-in/Product',[sys,'/','Product1'])
set_param([sys,'/','Product1'],...
		'orientation',2,...
		'BackGround',7,...
		'hide name',0,...
		'position',[275,75,305,130])

add_block('built-in/Clock',[sys,'/','Clock'])
set_param([sys,'/','Clock'],...
		'ForeGround',3,...
		'BackGround',6,...
		'hide name',0,...
		'position',[440,75,460,95])

add_block('built-in/To Workspace',[sys,'/','To Workspace'])
set_param([sys,'/','To Workspace'],...
		'ForeGround',3,...
		'BackGround',6,...
		'hide name',0,...
		'mat-name','temps',...
		'buffer','points_trace',...
		'position',[505,77,555,93])

add_block('built-in/Integrator',[sys,'/','Integrator1'])
set_param([sys,'/','Integrator1'],...
		'BackGround',2,...
		'hide name',0,...
		'position',[385,165,405,185])

add_block('built-in/To Workspace',[sys,'/','To Workspace1'])
set_param([sys,'/','To Workspace1'],...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','tangage',...
		'buffer','points_trace',...
		'position',[510,167,560,183])

add_block('built-in/Product',[sys,'/','Product'])
set_param([sys,'/','Product'],...
		'orientation',2,...
		'BackGround',7,...
		'hide name',0,...
		'position',[295,204,325,286])

add_block('built-in/MATLAB Fcn',[sys,'/','MATLAB Fcn'])
set_param([sys,'/','MATLAB Fcn'],...
		'orientation',2,...
		'BackGround',6,...
		'hide name',0,...
		'MATLAB Fcn','norm(u)*norm(u)',...
		'Output Width','1',...
		'Mask Display','GAIN B',...
		'position',[355,250,405,280])

add_block('built-in/Constant',[sys,'/','Constant1'])
set_param([sys,'/','Constant1'],...
		'orientation',2,...
		'BackGround',7,...
		'hide name',0,...
		'Value','3*vitesse_rotation^2*(Ir-Il)',...
		'position',[325,75,425,105])

add_block('built-in/Sum',[sys,'/','Sum'])
set_param([sys,'/','Sum'],...
		'BackGround',2,...
		'hide name',0,...
		'inputs','-++-',...
		'position',[200,113,225,237])

add_block('built-in/Gain',[sys,'/','Gain2'])
set_param([sys,'/','Gain2'],...
		'BackGround',7,...
		'hide name',0,...
		'position',[145,145,165,175])

add_block('built-in/Note',[sys,'/',['SIMULATION UNIAXE EN TANGAGE AVEC AMORTISSEMENT PAR LA DERIVEE',13,'DU CHAMP MAGNETIQUE TERRESTRE']])
set_param([sys,'/',['SIMULATION UNIAXE EN TANGAGE AVEC AMORTISSEMENT PAR LA DERIVEE',13,'DU CHAMP MAGNETIQUE TERRESTRE']],...
		'ForeGround',5,...
		'Font Name','Arial',...
		'Font Size',12,...
		'position',[300,15,301,16])

add_block('built-in/Note',[sys,'/','Sign: GUIZIOU 1994//95'])
set_param([sys,'/','Sign: GUIZIOU 1994//95'],...
		'ForeGround',5,...
		'position',[75,60,76,61])

add_block('built-in/Gain',[sys,'/','Gain3'])
set_param([sys,'/','Gain3'],...
		'BackGround',7,...
		'hide name',0,...
		'position',[145,175,165,205])

add_block('built-in/Gain',[sys,'/','Gain1'])
set_param([sys,'/','Gain1'],...
		'BackGround',2,...
		'hide name',0,...
		'Gain','-1/It',...
		'position',[255,155,285,195])

add_block('built-in/Scope',[sys,'/','Scope'])
set_param([sys,'/','Scope'],...
		'BackGround',5,...
		'hide name',0,...
		'Vgain','3.000000',...
		'Hgain','80000.000000',...
		'Vmax','6.000000',...
		'Hmax','160000.000000',...
		'Window',[16,78,610,464])
open_system([sys,'/','Scope'])
set_param([sys,'/','Scope'],...
		'position',[520,102,540,128])

add_block('built-in/Gain',[sys,'/','Gain'])
set_param([sys,'/','Gain'],...
		'orientation',2,...
		'BackGround',7,...
		'hide name',0,...
		'Gain','1e6',...
		'position',[225,225,255,265])

add_block('built-in/Note',[sys,'/',['INITIALISER EN LANCANT   SVCAODAT1',13,' ',13,'ou',13,'',13,'LOAD INITIAT']])
set_param([sys,'/',['INITIALISER EN LANCANT   SVCAODAT1',13,' ',13,'ou',13,'',13,'LOAD INITIAT']],...
		'ForeGround',3,...
		'position',[125,295,126,296])

add_block('built-in/Integrator',[sys,'/','Integrator'])
set_param([sys,'/','Integrator'],...
		'BackGround',2,...
		'hide name',0,...
		'position',[315,165,335,185])

add_block('built-in/To Workspace',[sys,'/','To Workspace2'])
set_param([sys,'/','To Workspace2'],...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','v_tangage',...
		'buffer','points_trace',...
		'position',[510,192,560,208])

add_block('built-in/From Workspace',[sys,'/','From Workspace'])
set_param([sys,'/','From Workspace'],...
		'orientation',2,...
		'hide name',0,...
		'matl_expr','[champ_magn_terr]',...
		'Mask Display','Champ magntique\nterrestre\n(repre orbital)',...
		'position',[465,236,570,294])

add_block('built-in/Gain',[sys,'/','Gain4'])
set_param([sys,'/','Gain4'],...
		'BackGround',7,...
		'hide name',0,...
		'Gain','1e6',...
		'position',[100,170,130,210])

add_block('built-in/Constant',[sys,'/','Constant3'])
set_param([sys,'/','Constant3'],...
		'BackGround',7,...
		'hide name',0,...
		'Value','2*constante_magnetic^2*vitesse_rotation',...
		'position',[15,178,80,212])
add_line(sys,[340,175;375,175])
add_line(sys,[410,175;500,175])
add_line(sys,[355,175;355,225;335,225])
add_line(sys,[290,245;265,245])
add_line(sys,[430,175;430,115;315,115])
add_line(sys,[320,90;315,90])
add_line(sys,[465,85;495,85])
add_line(sys,[430,115;510,115])
add_line(sys,[460,265;415,265])
add_line(sys,[350,265;335,265])
add_line(sys,[220,245;135,245;135,220;190,220])
add_line(sys,[290,175;305,175])
add_line(sys,[230,175;245,175])
add_line(sys,[65,160;135,160])
add_line(sys,[170,160;190,160])
add_line(sys,[170,190;190,190])
add_line(sys,[85,195;90,190])
add_line(sys,[135,190;135,190])
add_line(sys,[270,105;135,105;135,130;190,130])
add_line(sys,[355,225;355,220])
add_line(sys,[355,200;500,200])

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str] = feval(sys);
	end
end
