function [ret,x0,str]=scaoderf(t,x,u,flag);
%SCAODERF	is the M-file description of the SIMULINK system named SCAODERF.
%	The block-diagram can be displayed by typing: SCAODERF.
%
%	SYS=SCAODERF(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes SCAODERF to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling SCAODERF with a FLAG of zero:
%	[SIZES]=SCAODERF([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs.
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.2)
if(0 == (nargin + nargout))
     set_param(sys,'Location',[4,42,628,468])
     open_system(sys)
end;
set_param(sys,'BackGround',0)
set_param(sys,'algorithm',		'Linear')
set_param(sys,'Start time',	'0.0')
set_param(sys,'Stop time',		'tsim')
set_param(sys,'Min step size',	'tsim/400')
set_param(sys,'Max step size',	'tsim/500')
set_param(sys,'Relative error','1e-3')
set_param(sys,'Return vars',	'')


%     Subsystem  ['Calcul couples',13,'de commande'].

new_system([sys,'/',['Calcul couples',13,'de commande']])
set_param([sys,'/',['Calcul couples',13,'de commande']],'Location',[4,42,628,468])

add_block('built-in/Inport',[sys,'/',['Calcul couples',13,'de commande/in_4']])
set_param([sys,'/',['Calcul couples',13,'de commande/in_4']],...
		'Port','2',...
		'position',[165,160,185,180])

add_block('built-in/Outport',[sys,'/',['Calcul couples',13,'de commande/out_2']])
set_param([sys,'/',['Calcul couples',13,'de commande/out_2']],...
		'position',[355,145,375,165])

add_block('built-in/Inport',[sys,'/',['Calcul couples',13,'de commande/in_3']])
set_param([sys,'/',['Calcul couples',13,'de commande/in_3']],...
		'position',[165,125,185,145])

add_block('built-in/MATLAB Fcn',[sys,'/',['Calcul couples',13,'de commande/MATLAB Fcn1']])
set_param([sys,'/',['Calcul couples',13,'de commande/MATLAB Fcn1']],...
		'hide name',0,...
		'MATLAB Fcn','prodvect(u(1:3),u(4:6))',...
		'Output Width','3',...
		'position',[285,140,335,170])

add_block('built-in/Mux',[sys,'/',['Calcul couples',13,'de commande/Mux1']])
set_param([sys,'/',['Calcul couples',13,'de commande/Mux1']],...
		'hide name',0,...
		'inputs','[3 3]',...
		'position',[220,115,260,190])

add_block('built-in/Note',[sys,'/',['Calcul couples',13,'de commande/CALCUL DU COUPLE DE COMMANDE POUR  UNE COMMANDE',13,' PAR  LA DERIVEE DU CHAMP MAGNETIQUE']])
set_param([sys,'/',['Calcul couples',13,'de commande/CALCUL DU COUPLE DE COMMANDE POUR  UNE COMMANDE',13,' PAR  LA DERIVEE DU CHAMP MAGNETIQUE']],...
		'ForeGround',2,...
		'Font Name','Arial',...
		'Font Size',16)
set_param([sys,'/',['Calcul couples',13,'de commande/CALCUL DU COUPLE DE COMMANDE POUR  UNE COMMANDE',13,' PAR  LA DERIVEE DU CHAMP MAGNETIQUE']],...
		'position',[320,15,321,16])
add_line([sys,'/',['Calcul couples',13,'de commande']],[265,155;275,155])
add_line([sys,'/',['Calcul couples',13,'de commande']],[190,135;210,135])
add_line([sys,'/',['Calcul couples',13,'de commande']],[340,155;345,155])
add_line([sys,'/',['Calcul couples',13,'de commande']],[190,170;210,170])
set_param([sys,'/',['Calcul couples',13,'de commande']],...
		'Mask Display','Calcul\ndu couple\nde contrle Mc')


%     Finished composite block ['Calcul couples',13,'de commande'].

set_param([sys,'/',['Calcul couples',13,'de commande']],...
		'BackGround',7,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',10,...
		'position',[175,200,260,255])

add_block('built-in/Note',[sys,'/','M'])
set_param([sys,'/','M'],...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',10,...
		'position',[162,190,163,191])

add_block('built-in/Note',[sys,'/','Mc'])
set_param([sys,'/','Mc'],...
		'Font Name','Arial',...
		'Font Size',10,...
		'position',[280,230,281,231])


%     Subsystem  'UnNamed4'.

new_system([sys,'/','UnNamed4'])
set_param([sys,'/','UnNamed4'],'Location',[4,61,260,242])

add_block('built-in/Outport',[sys,'/','UnNamed4/out_1'])
set_param([sys,'/','UnNamed4/out_1'],...
		'position',[235,85,255,105])

add_block('built-in/Mux',[sys,'/','UnNamed4/Mux'])
set_param([sys,'/','UnNamed4/Mux'],...
		'inputs','3',...
		'position',[150,57,180,133])

add_block('built-in/Constant',[sys,'/','UnNamed4/Constant1'])
set_param([sys,'/','UnNamed4/Constant1'],...
		'hide name',0,...
		'Value','0',...
		'position',[65,60,85,80])

add_block('built-in/Constant',[sys,'/','UnNamed4/Constant2'])
set_param([sys,'/','UnNamed4/Constant2'],...
		'hide name',0,...
		'Value','0',...
		'position',[65,85,85,105])

add_block('built-in/Constant',[sys,'/','UnNamed4/Constant3'])
set_param([sys,'/','UnNamed4/Constant3'],...
		'hide name',0,...
		'Value','0',...
		'position',[65,110,85,130])
add_line([sys,'/','UnNamed4'],[90,70;140,70])
add_line([sys,'/','UnNamed4'],[90,95;140,95])
add_line([sys,'/','UnNamed4'],[90,120;140,120])
add_line([sys,'/','UnNamed4'],[185,95;225,95])
set_param([sys,'/','UnNamed4'],...
		'Mask Display','Consigne\nnulle')


%     Finished composite block 'UnNamed4'.

set_param([sys,'/','UnNamed4'],...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',10,...
		'position',[25,190,85,230])

add_block('built-in/Sum',[sys,'/','Sum1'])
set_param([sys,'/','Sum1'],...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',10,...
		'inputs','+-',...
		'position',[135,205,155,225])


%     Subsystem  ['Double click',13,'on this for demo.2'].

new_system([sys,'/',['Double click',13,'on this for demo.2']])
set_param([sys,'/',['Double click',13,'on this for demo.2']],'Location',[-10,380,117,533])
set_param([sys,'/',['Double click',13,'on this for demo.2']],...
		'Mask Display','MODELISATION AVEC COMMANDE MAGNETO-COUPLEURS PAR LA DERIVEE DU CHAMP MAGNETIQUE TERRESTRE',...
		'Mask Type','',...
		'Mask Dialogue',' ',...
		'Mask Translate','')
set_param([sys,'/',['Double click',13,'on this for demo.2']],...
		'Mask Help','')


%     Finished composite block ['Double click',13,'on this for demo.2'].

set_param([sys,'/',['Double click',13,'on this for demo.2']],...
		'ForeGround',2,...
		'BackGround',3,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',10,...
		'position',[20,10,610,56])

add_block('built-in/Sum',[sys,'/','Sum'])
set_param([sys,'/','Sum'],...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',10,...
		'position',[305,200,325,240])

add_block('built-in/Note',[sys,'/','Sign:GUIZIOU 1994//95'])
set_param([sys,'/','Sign:GUIZIOU 1994//95'],...
		'ForeGround',5,...
		'Font Name','Arial',...
		'Font Size',10,...
		'position',[525,60,526,61])

add_block('built-in/Note',[sys,'/','Brel'])
set_param([sys,'/','Brel'],...
		'ForeGround',5,...
		'Font Name','Arial',...
		'Font Size',10,...
		'position',[265,270,266,271])


%     Subsystem  'UnNamed'.

new_system([sys,'/','UnNamed'])
set_param([sys,'/','UnNamed'],'Location',[50,127,480,322])

add_block('built-in/Constant',[sys,'/','UnNamed/Constant3'])
set_param([sys,'/','UnNamed/Constant3'],...
		'hide name',0,...
		'Value','rayon_orbital',...
		'position',[65,129,155,161])

add_block('built-in/Constant',[sys,'/','UnNamed/Constant2'])
set_param([sys,'/','UnNamed/Constant2'],...
		'hide name',0,...
		'Value','inclinaison',...
		'position',[65,89,155,121])

add_block('built-in/MATLAB Fcn',[sys,'/','UnNamed/MATLAB Fcn'])
set_param([sys,'/','UnNamed/MATLAB Fcn'],...
		'MATLAB Fcn','champmgn(u)',...
		'position',[270,77,395,133])

add_block('built-in/Clock',[sys,'/','UnNamed/Clock'])
set_param([sys,'/','UnNamed/Clock'],...
		'position',[65,55,85,75])

add_block('built-in/Mux',[sys,'/','UnNamed/Mux'])
set_param([sys,'/','UnNamed/Mux'],...
		'inputs','3',...
		'position',[210,48,250,162])

add_block('built-in/Note',[sys,'/','UnNamed/Temps'])
set_param([sys,'/','UnNamed/Temps'],...
		'position',[125,50,126,51])

add_block('built-in/Outport',[sys,'/','UnNamed/out_1'])
set_param([sys,'/','UnNamed/out_1'],...
		'position',[415,95,435,115])
add_line([sys,'/','UnNamed'],[255,105;260,105])
add_line([sys,'/','UnNamed'],[160,145;200,145])
add_line([sys,'/','UnNamed'],[90,65;200,65])
add_line([sys,'/','UnNamed'],[160,105;200,105])
add_line([sys,'/','UnNamed'],[400,105;405,105])
set_param([sys,'/','UnNamed'],...
		'Mask Display','CHAMP TERRESTRE\nEN REPERE ORBITAL')


%     Finished composite block 'UnNamed'.

set_param([sys,'/','UnNamed'],...
		'orientation',2,...
		'hide name',0,...
		'position',[525,270,640,320])

add_block('built-in/Note',[sys,'/',' TANGAGE ET ROULIS'])
set_param([sys,'/',' TANGAGE ET ROULIS'],...
		'ForeGround',3,...
		'Font Name','Arial',...
		'Font Size',10,...
		'position',[575,90,576,91])

add_block('built-in/Demux',[sys,'/','Demux1'])
set_param([sys,'/','Demux1'],...
		'BackGround',3,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',10,...
		'outputs','6',...
		'position',[510,119,530,181])

add_block('built-in/Scope',[sys,'/','Scope'])
set_param([sys,'/','Scope'],...
		'BackGround',5,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',10,...
		'Vgain','1.000000',...
		'Hgain','40000.000000',...
		'Vmax','2.000000',...
		'Hmax','80000.000000')
set_param([sys,'/','Scope'],...
		'Window',[0,256,623,473])
open_system([sys,'/','Scope'])
set_param([sys,'/','Scope'],...
		'position',[580,339,620,381])

add_block('built-in/Demux',[sys,'/','Demux'])
set_param([sys,'/','Demux'],...
		'BackGround',5,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',10,...
		'outputs','6',...
		'position',[525,333,555,372])


%     Subsystem  ['Calcul champ magntique',13,'terrestre'].

new_system([sys,'/',['Calcul champ magntique',13,'terrestre']])
set_param([sys,'/',['Calcul champ magntique',13,'terrestre']],'Location',[4,42,628,468])

add_block('built-in/Inport',[sys,'/',['Calcul champ magntique',13,'terrestre/in_2']])
set_param([sys,'/',['Calcul champ magntique',13,'terrestre/in_2']],...
		'Port','2',...
		'position',[10,160,30,180])

add_block('built-in/Note',[sys,'/',['Calcul champ magntique',13,'terrestre/Vecteur',13,'d''tat']])
set_param([sys,'/',['Calcul champ magntique',13,'terrestre/Vecteur',13,'d''tat']],...
		'position',[53,140,54,141])

add_block('built-in/Inport',[sys,'/',['Calcul champ magntique',13,'terrestre/in_1']])
set_param([sys,'/',['Calcul champ magntique',13,'terrestre/in_1']],...
		'position',[10,115,30,135])

add_block('built-in/Note',[sys,'/',['Calcul champ magntique',13,'terrestre/Champ magntique',13,'terrestre',13,'(repre orbital)']])
set_param([sys,'/',['Calcul champ magntique',13,'terrestre/Champ magntique',13,'terrestre',13,'(repre orbital)']],...
		'position',[100,80,101,81])

add_block('built-in/Mux',[sys,'/',['Calcul champ magntique',13,'terrestre/Mux4']])
set_param([sys,'/',['Calcul champ magntique',13,'terrestre/Mux4']],...
		'hide name',0,...
		'inputs','[3 3]',...
		'position',[165,100,200,195])

add_block('built-in/State-space',[sys,'/',['Calcul champ magntique',13,'terrestre/Matrix gain.4']])
set_param([sys,'/',['Calcul champ magntique',13,'terrestre/Matrix gain.4']],...
		'A','[]',...
		'B','[]',...
		'C','[]',...
		'D','K',...
		'Mask Display','matrice',...
		'Mask Type','Matrix gain')
set_param([sys,'/',['Calcul champ magntique',13,'terrestre/Matrix gain.4']],...
		'Mask Dialogue','Matrix Gain:|Gain matrix:',...
		'Mask Translate','K = @1;',...
		'Mask Help','Multiplies input vector by entered matrix to produce output vector.')
set_param([sys,'/',['Calcul champ magntique',13,'terrestre/Matrix gain.4']],...
		'Mask Entries','[1 0 0 0 0 0;0 0 1 0 0 0 ;0 0 0 0 1 0]\/',...
		'position',[75,153,130,187])

add_block('built-in/Note',[sys,'/',['Calcul champ magntique',13,'terrestre/Champ magntique',13,'terrestre',13,'(repre satellite)']])
set_param([sys,'/',['Calcul champ magntique',13,'terrestre/Champ magntique',13,'terrestre',13,'(repre satellite)']],...
		'position',[471,135,472,136])

add_block('built-in/Outport',[sys,'/',['Calcul champ magntique',13,'terrestre/out_1']])
set_param([sys,'/',['Calcul champ magntique',13,'terrestre/out_1']],...
		'Mask Display','',...
		'position',[390,140,410,160])

add_block('built-in/MATLAB Fcn',[sys,'/',['Calcul champ magntique',13,'terrestre/MATLAB Fcn']])
set_param([sys,'/',['Calcul champ magntique',13,'terrestre/MATLAB Fcn']],...
		'hide name',0,...
		'MATLAB Fcn','passage(u)',...
		'Output Width','3',...
		'Mask Display','CHANGEMENT\nDE BASE',...
		'position',[245,127,345,173])
add_line([sys,'/',['Calcul champ magntique',13,'terrestre']],[35,125;155,125])
add_line([sys,'/',['Calcul champ magntique',13,'terrestre']],[35,170;65,170])
add_line([sys,'/',['Calcul champ magntique',13,'terrestre']],[135,170;155,170])
add_line([sys,'/',['Calcul champ magntique',13,'terrestre']],[205,150;235,150])
add_line([sys,'/',['Calcul champ magntique',13,'terrestre']],[350,150;380,150])
set_param([sys,'/',['Calcul champ magntique',13,'terrestre']],...
		'Mask Display','Calcul du champ\nmagntique terrestre\n(repre satellite)')


%     Finished composite block ['Calcul champ magntique',13,'terrestre'].

set_param([sys,'/',['Calcul champ magntique',13,'terrestre']],...
		'orientation',2,...
		'BackGround',7,...
		'Font Name','Arial',...
		'Font Size',10,...
		'position',[345,280,480,335])

add_block('built-in/Gain',[sys,'/','Gain1'])
set_param([sys,'/','Gain1'],...
		'orientation',3,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',10,...
		'Gain','1/200000',...
		'position',[75,240,115,270])

add_block('built-in/State-space',[sys,'/','State-space'])
set_param([sys,'/','State-space'],...
		'ForeGround',1,...
		'BackGround',2,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',10,...
		'A','Asat',...
		'B','Bsat',...
		'C','eye(Asat)',...
		'D','zeros(Bsat)')
set_param([sys,'/','State-space'],...
		'X0','[0.1 0 0.1 0 0.05 0.005]''',...
		'Mask Display','MODELE\nSATELLITE',...
		'position',[350,191,495,249])

add_block('built-in/To Workspace',[sys,'/','To Workspace'])
set_param([sys,'/','To Workspace'],...
		'ForeGround',3,...
		'BackGround',6,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',10,...
		'mat-name','temps',...
		'buffer','points_trace',...
		'position',[430,102,480,118])

add_block('built-in/Clock',[sys,'/','Clock'])
set_param([sys,'/','Clock'],...
		'ForeGround',3,...
		'BackGround',6,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',10,...
		'position',[340,100,360,120])

add_block('built-in/Mux',[sys,'/','Mux'])
set_param([sys,'/','Mux'],...
		'BackGround',3,...
		'inputs','2',...
		'position',[545,115,570,155])

add_block('built-in/Scope',[sys,'/','Scope1'])
set_param([sys,'/','Scope1'],...
		'BackGround',3,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',10,...
		'Vgain','0.150000',...
		'Hgain','40000.000000',...
		'Vmax','0.300000',...
		'Hmax','80000.000000')
set_param([sys,'/','Scope1'],...
		'Window',[0,42,623,259])
open_system([sys,'/','Scope1'])
set_param([sys,'/','Scope1'],...
		'position',[585,114,625,156])


%     Subsystem  'Gain '.

new_system([sys,'/','Gain '])
set_param([sys,'/','Gain '],'Location',[30,105,430,375])

add_block('built-in/Inport',[sys,'/','Gain /in_1'])
set_param([sys,'/','Gain /in_1'],...
		'position',[15,95,35,115])

add_block('built-in/Inport',[sys,'/','Gain /in_2'])
set_param([sys,'/','Gain /in_2'],...
		'Port','2',...
		'position',[15,195,35,215])

add_block('built-in/Outport',[sys,'/','Gain /out_1'])
set_param([sys,'/','Gain /out_1'],...
		'position',[385,130,405,150])


%     Subsystem  'Gain /UnNamed'.

new_system([sys,'/','Gain /UnNamed'])
set_param([sys,'/','Gain /UnNamed'],'Location',[15,120,405,385])

add_block('built-in/MATLAB Fcn',[sys,'/','Gain /UnNamed/MATLAB Fcn1'])
set_param([sys,'/','Gain /UnNamed/MATLAB Fcn1'],...
		'hide name',0,...
		'MATLAB Fcn','gain_mul(u)',...
		'Output Width','3',...
		'position',[310,135,360,165])

add_block('built-in/Mux',[sys,'/','Gain /UnNamed/Mux2'])
set_param([sys,'/','Gain /UnNamed/Mux2'],...
		'hide name',0,...
		'inputs','3',...
		'position',[130,112,170,188])

add_block('built-in/Constant',[sys,'/','Gain /UnNamed/Constant2'])
set_param([sys,'/','Gain /UnNamed/Constant2'],...
		'hide name',0,...
		'Value','Ir',...
		'position',[55,115,100,135])

add_block('built-in/Constant',[sys,'/','Gain /UnNamed/Constant3'])
set_param([sys,'/','Gain /UnNamed/Constant3'],...
		'hide name',0,...
		'Value','It',...
		'position',[55,140,100,160])

add_block('built-in/Constant',[sys,'/','Gain /UnNamed/Constant4'])
set_param([sys,'/','Gain /UnNamed/Constant4'],...
		'hide name',0,...
		'Value','Il',...
		'position',[55,165,100,185])

add_block('built-in/Mux',[sys,'/','Gain /UnNamed/Mux1'])
set_param([sys,'/','Gain /UnNamed/Mux1'],...
		'hide name',0,...
		'inputs','[3 3 3]',...
		'position',[220,75,265,225])

add_block('built-in/Inport',[sys,'/','Gain /UnNamed/in_1'])
set_param([sys,'/','Gain /UnNamed/in_1'],...
		'position',[15,90,35,110])

add_block('built-in/Outport',[sys,'/','Gain /UnNamed/out_1'])
set_param([sys,'/','Gain /UnNamed/out_1'],...
		'position',[375,140,395,160])

add_block('built-in/Inport',[sys,'/','Gain /UnNamed/in_2'])
set_param([sys,'/','Gain /UnNamed/in_2'],...
		'Port','2',...
		'position',[15,190,35,210])
add_line([sys,'/','Gain /UnNamed'],[270,150;300,150])
add_line([sys,'/','Gain /UnNamed'],[175,150;210,150])
add_line([sys,'/','Gain /UnNamed'],[105,125;120,125])
add_line([sys,'/','Gain /UnNamed'],[105,150;120,150])
add_line([sys,'/','Gain /UnNamed'],[105,175;120,175])
add_line([sys,'/','Gain /UnNamed'],[40,100;210,100])
add_line([sys,'/','Gain /UnNamed'],[365,150;365,150])
add_line([sys,'/','Gain /UnNamed'],[40,200;210,200])
set_param([sys,'/','Gain /UnNamed'],...
		'Mask Display','Gain')


%     Finished composite block 'Gain /UnNamed'.

set_param([sys,'/','Gain /UnNamed'],...
		'position',[165,122,195,173])
add_line([sys,'/','Gain '],[200,150;375,150;375,140])
add_line([sys,'/','Gain '],[40,105;45,105;45,135;155,135])
add_line([sys,'/','Gain '],[40,205;45,205;45,160;155,160])
set_param([sys,'/','Gain '],...
		'Mask Display','Gain')


%     Finished composite block 'Gain '.

set_param([sys,'/','Gain '],...
		'orientation',2,...
		'ForeGround',1,...
		'BackGround',6,...
		'position',[115,282,165,318])

add_block('built-in/Note',[sys,'/','Mp'])
set_param([sys,'/','Mp'],...
		'Font Name','Arial',...
		'Font Size',10,...
		'position',[245,95,246,96])


%     Subsystem  ['Perturbations',13,'arodynamiques'].

new_system([sys,'/',['Perturbations',13,'arodynamiques']])
set_param([sys,'/',['Perturbations',13,'arodynamiques']],'Location',[4,42,628,468])

add_block('built-in/Outport',[sys,'/',['Perturbations',13,'arodynamiques/out_1']])
set_param([sys,'/',['Perturbations',13,'arodynamiques/out_1']],...
		'Mask Display','',...
		'position',[535,90,555,110])

add_block('built-in/Note',[sys,'/',['Perturbations',13,'arodynamiques/Force arodynamique ',13,'(repre satellite)']])
set_param([sys,'/',['Perturbations',13,'arodynamiques/Force arodynamique ',13,'(repre satellite)']],...
		'position',[386,40,387,41])

add_block('built-in/MATLAB Fcn',[sys,'/',['Perturbations',13,'arodynamiques/MATLAB Fcn']])
set_param([sys,'/',['Perturbations',13,'arodynamiques/MATLAB Fcn']],...
		'hide name',0,...
		'MATLAB Fcn','passage(u)',...
		'Output Width','3',...
		'Mask Display','CHANGEMENT\nDE BASE',...
		'position',[245,77,345,123])

add_block('built-in/Note',[sys,'/',['Perturbations',13,'arodynamiques/Vecteur',13,'d''tat']])
set_param([sys,'/',['Perturbations',13,'arodynamiques/Vecteur',13,'d''tat']],...
		'position',[83,130,84,131])

add_block('built-in/Mux',[sys,'/',['Perturbations',13,'arodynamiques/Mux4']])
set_param([sys,'/',['Perturbations',13,'arodynamiques/Mux4']],...
		'hide name',0,...
		'inputs','[3 3]',...
		'position',[190,50,225,145])

add_block('built-in/Note',[sys,'/',['Perturbations',13,'arodynamiques/Force arodynamique ',13,'(repre orbital)']])
set_param([sys,'/',['Perturbations',13,'arodynamiques/Force arodynamique ',13,'(repre orbital)']],...
		'position',[145,30,146,31])

add_block('built-in/State-space',[sys,'/',['Perturbations',13,'arodynamiques/Matrix gain.4']])
set_param([sys,'/',['Perturbations',13,'arodynamiques/Matrix gain.4']],...
		'A','[]',...
		'B','[]',...
		'C','[]',...
		'D','K',...
		'Mask Display','matrice',...
		'Mask Type','Matrix gain',...
		'Mask Dialogue','Matrix Gain:|Gain matrix:')
set_param([sys,'/',['Perturbations',13,'arodynamiques/Matrix gain.4']],...
		'Mask Translate','K = @1;',...
		'Mask Help','Multiplies input vector by entered matrix to produce output vector.')
set_param([sys,'/',['Perturbations',13,'arodynamiques/Matrix gain.4']],...
		'Mask Entries','[1 0 0 0 0 0;0 0 1 0 0 0 ;0 0 0 0 1 0]\/',...
		'position',[115,103,170,137])

add_block('built-in/Inport',[sys,'/',['Perturbations',13,'arodynamiques/in_1']])
set_param([sys,'/',['Perturbations',13,'arodynamiques/in_1']],...
		'position',[20,110,40,130])

add_block('built-in/Note',[sys,'/',['Perturbations',13,'arodynamiques/MOMENT',13,' AERODYNAMIQUE',13,'EN AXES SATELLITE']])
set_param([sys,'/',['Perturbations',13,'arodynamiques/MOMENT',13,' AERODYNAMIQUE',13,'EN AXES SATELLITE']],...
		'position',[565,35,566,36])

add_block('built-in/Gain',[sys,'/',['Perturbations',13,'arodynamiques/Gain']])
set_param([sys,'/',['Perturbations',13,'arodynamiques/Gain']],...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',10,...
		'Gain','COUPLE_AERO',...
		'position',[445,87,480,113])

add_block('built-in/Note',[sys,'/',['Perturbations',13,'arodynamiques/La matrice K ralise le produit vectoriel z^',13,'']])
set_param([sys,'/',['Perturbations',13,'arodynamiques/La matrice K ralise le produit vectoriel z^',13,'']],...
		'position',[435,135,436,136])

add_block('built-in/Note',[sys,'/',['Perturbations',13,'arodynamiques/Le gain rtablit le signe et donne l''influence du dcentrage']])
set_param([sys,'/',['Perturbations',13,'arodynamiques/Le gain rtablit le signe et donne l''influence du dcentrage']],...
		'position',[350,165,351,166])

add_block('built-in/Note',[sys,'/',['Perturbations',13,'arodynamiques/w']])
set_param([sys,'/',['Perturbations',13,'arodynamiques/w']],...
		'position',[30,380,31,381])

add_block('built-in/Constant',[sys,'/',['Perturbations',13,'arodynamiques/Constant4']])
set_param([sys,'/',['Perturbations',13,'arodynamiques/Constant4']],...
		'hide name',0,...
		'Value','[1 0 0]',...
		'position',[105,64,170,86])

add_block('built-in/State-space',[sys,'/',['Perturbations',13,'arodynamiques/Matrix gain.']])
set_param([sys,'/',['Perturbations',13,'arodynamiques/Matrix gain.']],...
		'A','[]',...
		'B','[]',...
		'C','[]',...
		'D','K',...
		'Mask Display','K',...
		'Mask Type','Matrix gain',...
		'Mask Dialogue','Matrix Gain.|Gain matrix:')
set_param([sys,'/',['Perturbations',13,'arodynamiques/Matrix gain.']],...
		'Mask Translate','K = @1;',...
		'Mask Help','Multiplies input vector by entered matrix to produce output vector (y=Au).',...
		'Mask Entries','[0 -1 0;1 0 0;0 0 0]\/')
set_param([sys,'/',['Perturbations',13,'arodynamiques/Matrix gain.']],...
		'position',[365,83,420,117])
add_line([sys,'/',['Perturbations',13,'arodynamiques']],[175,75;180,75])
add_line([sys,'/',['Perturbations',13,'arodynamiques']],[45,120;105,120])
add_line([sys,'/',['Perturbations',13,'arodynamiques']],[175,120;180,120])
add_line([sys,'/',['Perturbations',13,'arodynamiques']],[230,100;235,100])
add_line([sys,'/',['Perturbations',13,'arodynamiques']],[350,100;355,100])
add_line([sys,'/',['Perturbations',13,'arodynamiques']],[425,100;435,100])
add_line([sys,'/',['Perturbations',13,'arodynamiques']],[485,100;525,100])
set_param([sys,'/',['Perturbations',13,'arodynamiques']],...
		'Mask Display','Couples\nperturbateurs Mp')


%     Finished composite block ['Perturbations',13,'arodynamiques'].

set_param([sys,'/',['Perturbations',13,'arodynamiques']],...
		'ForeGround',2,...
		'Font Name','Arial',...
		'Font Size',10,...
		'position',[55,69,155,121])

add_block('built-in/Gain',[sys,'/','Gain'])
set_param([sys,'/','Gain'],...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',10,...
		'position',[180,82,215,108])

add_block('built-in/Note',[sys,'/','B'])
set_param([sys,'/','B'],...
		'Font Name','Arial',...
		'Font Size',10,...
		'position',[316,315,317,316])

add_block('built-in/Derivative',[sys,'/','Derivative'])
set_param([sys,'/','Derivative'],...
		'orientation',2,...
		'BackGround',7,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',10,...
		'position',[225,295,280,325])
add_line(sys,[160,215;165,215])
add_line(sys,[90,210;125,210])
add_line(sys,[520,295;490,295])
add_line(sys,[365,110;420,110])
add_line(sys,[160,95;170,95])
add_line(sys,[220,95;285,95;285,210;295,210])
add_line(sys,[265,230;295,230])
add_line(sys,[500,220;505,215])
add_line(sys,[340,310;300,310;300,265;130,265;130,240;165,240])
add_line(sys,[300,310;290,310])
add_line(sys,[500,220;500,320;490,320])
add_line(sys,[500,320;500,355;515,355])
add_line(sys,[500,220;500,150])
add_line(sys,[560,360;570,360])
add_line(sys,[575,135;575,135])
add_line(sys,[535,125;535,125])
add_line(sys,[535,145;535,145])
add_line(sys,[220,265;220,290;175,290])
add_line(sys,[220,310;175,310])
add_line(sys,[330,220;340,220])
add_line(sys,[110,300;95,300;95,280])
add_line(sys,[95,235;95,220;125,220])
add_line(sys,[500,165;30,165;30,95;45,95])

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str] = feval(sys);
	end
end
