function [ret,x0,str]=scaoderx(t,x,u,flag);
%SCAODERX	is the M-file description of the SIMULINK system named SCAODERX.
%	The block-diagram can be displayed by typing: SCAODERX.
%
%	SYS=SCAODERX(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes SCAODERX to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling SCAODERX with a FLAG of zero:
%	[SIZES]=SCAODERX([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs.
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.2)
if(0 == (nargin + nargout))
     set_param(sys,'Location',[4,42,628,468])
     open_system(sys)
end;
set_param(sys,'BackGround',0)
set_param(sys,'algorithm',		'Linear')
set_param(sys,'Start time',	'0.0')
set_param(sys,'Stop time',		'tsim')
set_param(sys,'Min step size',	'tsim/1000')
set_param(sys,'Max step size',	'tsim/500')
set_param(sys,'Relative error','1e-3')
set_param(sys,'Return vars',	'')


%     Subsystem  ['Calcul couples',13,'de commande'].

new_system([sys,'/',['Calcul couples',13,'de commande']])
set_param([sys,'/',['Calcul couples',13,'de commande']],'Location',[4,42,628,468])

add_block('built-in/Note',[sys,'/',['Calcul couples',13,'de commande/CALCUL DU COUPLE DE COMMANDE POUR  UNE COMMANDE',13,' PAR  LA DERIVEE DU CHAMP MAGNETIQUE']])
set_param([sys,'/',['Calcul couples',13,'de commande/CALCUL DU COUPLE DE COMMANDE POUR  UNE COMMANDE',13,' PAR  LA DERIVEE DU CHAMP MAGNETIQUE']],...
		'ForeGround',2,...
		'Font Name','Arial',...
		'Font Size',16)
set_param([sys,'/',['Calcul couples',13,'de commande/CALCUL DU COUPLE DE COMMANDE POUR  UNE COMMANDE',13,' PAR  LA DERIVEE DU CHAMP MAGNETIQUE']],...
		'position',[320,15,321,16])

add_block('built-in/Demux',[sys,'/',['Calcul couples',13,'de commande/Demux']])
set_param([sys,'/',['Calcul couples',13,'de commande/Demux']],...
		'outputs','3',...
		'position',[280,157,310,223])

add_block('built-in/Unit Delay',[sys,'/',['Calcul couples',13,'de commande/Unit Delay']])
set_param([sys,'/',['Calcul couples',13,'de commande/Unit Delay']],...
		'Sample time','temps_echant',...
		'position',[345,162,395,178])

add_block('built-in/Unit Delay',[sys,'/',['Calcul couples',13,'de commande/Unit Delay2']])
set_param([sys,'/',['Calcul couples',13,'de commande/Unit Delay2']],...
		'Sample time','temps_echant',...
		'position',[345,182,395,198])

add_block('built-in/Unit Delay',[sys,'/',['Calcul couples',13,'de commande/Unit Delay1']])
set_param([sys,'/',['Calcul couples',13,'de commande/Unit Delay1']],...
		'Sample time','temps_echant',...
		'position',[345,202,395,218])

add_block('built-in/Mux',[sys,'/',['Calcul couples',13,'de commande/Mux']])
set_param([sys,'/',['Calcul couples',13,'de commande/Mux']],...
		'inputs','3',...
		'position',[440,157,470,223])

add_block('built-in/Outport',[sys,'/',['Calcul couples',13,'de commande/out_2']])
set_param([sys,'/',['Calcul couples',13,'de commande/out_2']],...
		'position',[490,180,510,200])

add_block('built-in/Mux',[sys,'/',['Calcul couples',13,'de commande/Mux1']])
set_param([sys,'/',['Calcul couples',13,'de commande/Mux1']],...
		'hide name',0,...
		'inputs','[3 3]',...
		'position',[135,150,175,225])

add_block('built-in/MATLAB Fcn',[sys,'/',['Calcul couples',13,'de commande/MATLAB Fcn1']])
set_param([sys,'/',['Calcul couples',13,'de commande/MATLAB Fcn1']],...
		'hide name',0,...
		'MATLAB Fcn','prodvect(u(1:3),u(4:6))',...
		'Output Width','3',...
		'position',[200,175,250,205])

add_block('built-in/Inport',[sys,'/',['Calcul couples',13,'de commande/in_3']])
set_param([sys,'/',['Calcul couples',13,'de commande/in_3']],...
		'position',[80,160,100,180])

add_block('built-in/Inport',[sys,'/',['Calcul couples',13,'de commande/in_4']])
set_param([sys,'/',['Calcul couples',13,'de commande/in_4']],...
		'Port','2',...
		'position',[80,195,100,215])

add_block('built-in/Note',[sys,'/',['Calcul couples',13,'de commande/ECHANTILLONAGE AU TEMPS =====>  temp_echant']])
set_param([sys,'/',['Calcul couples',13,'de commande/ECHANTILLONAGE AU TEMPS =====>  temp_echant']],...
		'Font Size',14,...
		'position',[310,85,311,86])
add_line([sys,'/',['Calcul couples',13,'de commande']],[180,190;190,190])
add_line([sys,'/',['Calcul couples',13,'de commande']],[105,170;125,170])
add_line([sys,'/',['Calcul couples',13,'de commande']],[105,205;125,205])
add_line([sys,'/',['Calcul couples',13,'de commande']],[315,210;335,210])
add_line([sys,'/',['Calcul couples',13,'de commande']],[400,210;430,210])
add_line([sys,'/',['Calcul couples',13,'de commande']],[315,190;335,190])
add_line([sys,'/',['Calcul couples',13,'de commande']],[400,190;430,190])
add_line([sys,'/',['Calcul couples',13,'de commande']],[315,170;335,170])
add_line([sys,'/',['Calcul couples',13,'de commande']],[400,170;430,170])
add_line([sys,'/',['Calcul couples',13,'de commande']],[255,190;270,190])
add_line([sys,'/',['Calcul couples',13,'de commande']],[475,190;480,190])
set_param([sys,'/',['Calcul couples',13,'de commande']],...
		'Mask Display','Calcul\ndu couple\nde contrle Mc')


%     Finished composite block ['Calcul couples',13,'de commande'].

set_param([sys,'/',['Calcul couples',13,'de commande']],...
		'BackGround',7,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',10,...
		'position',[175,200,260,255])

add_block('built-in/Derivative',[sys,'/','Derivative'])
set_param([sys,'/','Derivative'],...
		'orientation',2,...
		'BackGround',7,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',10,...
		'position',[220,295,275,325])

add_block('built-in/Note',[sys,'/','Brel'])
set_param([sys,'/','Brel'],...
		'ForeGround',5,...
		'Font Name','Arial',...
		'Font Size',10,...
		'position',[215,270,216,271])

add_block('built-in/Gain',[sys,'/','Gain1'])
set_param([sys,'/','Gain1'],...
		'orientation',2,...
		'BackGround',6,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',10,...
		'Gain','1e7',...
		'position',[155,297,190,323])

add_block('built-in/Note',[sys,'/',['MOMENT',13,'MAGNETIQUE']])
set_param([sys,'/',['MOMENT',13,'MAGNETIQUE']],...
		'BackGround',6,...
		'Font Name','Arial',...
		'Font Size',10,...
		'position',[65,255,66,256])

add_block('built-in/Note',[sys,'/','GAIN'])
set_param([sys,'/','GAIN'],...
		'BackGround',6,...
		'Font Name','Arial',...
		'Font Size',10,...
		'position',[180,325,181,326])


%     Subsystem  ['Variables',13,'de commande1'].

new_system([sys,'/',['Variables',13,'de commande1']])
set_param([sys,'/',['Variables',13,'de commande1']],'Location',[4,42,628,468])

add_block('built-in/To Workspace',[sys,'/',['Variables',13,'de commande1/To Workspace2']])
set_param([sys,'/',['Variables',13,'de commande1/To Workspace2']],...
		'hide name',0,...
		'mat-name','mz',...
		'buffer','points_trace',...
		'position',[135,136,215,154])

add_block('built-in/To Workspace',[sys,'/',['Variables',13,'de commande1/To Workspace1']])
set_param([sys,'/',['Variables',13,'de commande1/To Workspace1']],...
		'hide name',0,...
		'mat-name','my',...
		'buffer','points_trace',...
		'position',[135,106,215,124])

add_block('built-in/Demux',[sys,'/',['Variables',13,'de commande1/Demux']])
set_param([sys,'/',['Variables',13,'de commande1/Demux']],...
		'hide name',0,...
		'outputs','3',...
		'position',[65,67,105,163])

add_block('built-in/To Workspace',[sys,'/',['Variables',13,'de commande1/To Workspace']])
set_param([sys,'/',['Variables',13,'de commande1/To Workspace']],...
		'hide name',0,...
		'mat-name','mx',...
		'buffer','points_trace',...
		'position',[135,76,215,94])

add_block('built-in/Inport',[sys,'/',['Variables',13,'de commande1/in_1']])
set_param([sys,'/',['Variables',13,'de commande1/in_1']],...
		'position',[15,105,35,125])
add_line([sys,'/',['Variables',13,'de commande1']],[110,145;125,145])
add_line([sys,'/',['Variables',13,'de commande1']],[110,115;125,115])
add_line([sys,'/',['Variables',13,'de commande1']],[110,85;125,85])
add_line([sys,'/',['Variables',13,'de commande1']],[40,115;55,115])
set_param([sys,'/',['Variables',13,'de commande1']],...
		'Mask Display','MOMENT\nMAGNETIQUE')


%     Finished composite block ['Variables',13,'de commande1'].

set_param([sys,'/',['Variables',13,'de commande1']],...
		'orientation',2,...
		'ForeGround',1,...
		'BackGround',4,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',10,...
		'position',[20,319,120,361])

add_block('built-in/Note',[sys,'/','B'])
set_param([sys,'/','B'],...
		'Font Name','Arial',...
		'Font Size',10,...
		'position',[291,320,292,321])

add_block('built-in/Note',[sys,'/','M'])
set_param([sys,'/','M'],...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',10,...
		'position',[162,190,163,191])

add_block('built-in/Note',[sys,'/','Mp'])
set_param([sys,'/','Mp'],...
		'Font Name','Arial',...
		'Font Size',10,...
		'position',[235,105,236,106])

add_block('built-in/Gain',[sys,'/','Gain'])
set_param([sys,'/','Gain'],...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',10,...
		'position',[170,107,205,133])


%     Subsystem  ['Perturbations',13,'arodynamiques'].

new_system([sys,'/',['Perturbations',13,'arodynamiques']])
set_param([sys,'/',['Perturbations',13,'arodynamiques']],'Location',[4,42,628,468])

add_block('built-in/Outport',[sys,'/',['Perturbations',13,'arodynamiques/out_1']])
set_param([sys,'/',['Perturbations',13,'arodynamiques/out_1']],...
		'position',[235,85,255,105])

add_block('built-in/Mux',[sys,'/',['Perturbations',13,'arodynamiques/Mux']])
set_param([sys,'/',['Perturbations',13,'arodynamiques/Mux']],...
		'inputs','3',...
		'position',[150,57,180,133])

add_block('built-in/Constant',[sys,'/',['Perturbations',13,'arodynamiques/Constant1']])
set_param([sys,'/',['Perturbations',13,'arodynamiques/Constant1']],...
		'hide name',0,...
		'Value','0',...
		'position',[40,60,85,80])

add_block('built-in/Constant',[sys,'/',['Perturbations',13,'arodynamiques/Constant2']])
set_param([sys,'/',['Perturbations',13,'arodynamiques/Constant2']],...
		'hide name',0,...
		'Value','5e-6',...
		'position',[40,85,85,105])

add_block('built-in/Constant',[sys,'/',['Perturbations',13,'arodynamiques/Constant3']])
set_param([sys,'/',['Perturbations',13,'arodynamiques/Constant3']],...
		'hide name',0,...
		'Value','0',...
		'position',[40,110,85,130])
add_line([sys,'/',['Perturbations',13,'arodynamiques']],[90,70;140,70])
add_line([sys,'/',['Perturbations',13,'arodynamiques']],[90,95;140,95])
add_line([sys,'/',['Perturbations',13,'arodynamiques']],[90,120;140,120])
add_line([sys,'/',['Perturbations',13,'arodynamiques']],[185,95;225,95])
set_param([sys,'/',['Perturbations',13,'arodynamiques']],...
		'Mask Display','Couples\nperturbateurs Mp')


%     Finished composite block ['Perturbations',13,'arodynamiques'].

set_param([sys,'/',['Perturbations',13,'arodynamiques']],...
		'ForeGround',2,...
		'Font Name','Arial',...
		'Font Size',10,...
		'position',[25,95,125,145])

add_block('built-in/Note',[sys,'/','Mc'])
set_param([sys,'/','Mc'],...
		'Font Name','Arial',...
		'Font Size',10,...
		'position',[280,230,281,231])


%     Subsystem  'UnNamed4'.

new_system([sys,'/','UnNamed4'])
set_param([sys,'/','UnNamed4'],'Location',[4,61,260,242])

add_block('built-in/Outport',[sys,'/','UnNamed4/out_1'])
set_param([sys,'/','UnNamed4/out_1'],...
		'position',[235,85,255,105])

add_block('built-in/Mux',[sys,'/','UnNamed4/Mux'])
set_param([sys,'/','UnNamed4/Mux'],...
		'inputs','3',...
		'position',[150,57,180,133])

add_block('built-in/Constant',[sys,'/','UnNamed4/Constant1'])
set_param([sys,'/','UnNamed4/Constant1'],...
		'hide name',0,...
		'Value','0',...
		'position',[65,60,85,80])

add_block('built-in/Constant',[sys,'/','UnNamed4/Constant2'])
set_param([sys,'/','UnNamed4/Constant2'],...
		'hide name',0,...
		'Value','0',...
		'position',[65,85,85,105])

add_block('built-in/Constant',[sys,'/','UnNamed4/Constant3'])
set_param([sys,'/','UnNamed4/Constant3'],...
		'hide name',0,...
		'Value','0',...
		'position',[65,110,85,130])
add_line([sys,'/','UnNamed4'],[90,70;140,70])
add_line([sys,'/','UnNamed4'],[90,95;140,95])
add_line([sys,'/','UnNamed4'],[90,120;140,120])
add_line([sys,'/','UnNamed4'],[185,95;225,95])
set_param([sys,'/','UnNamed4'],...
		'Mask Display','Consigne\nnulle')


%     Finished composite block 'UnNamed4'.

set_param([sys,'/','UnNamed4'],...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',10,...
		'position',[25,190,85,230])

add_block('built-in/Sum',[sys,'/','Sum1'])
set_param([sys,'/','Sum1'],...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',10,...
		'inputs','+-',...
		'position',[135,205,155,225])


%     Subsystem  ['Double click',13,'on this for demo.2'].

new_system([sys,'/',['Double click',13,'on this for demo.2']])
set_param([sys,'/',['Double click',13,'on this for demo.2']],'Location',[-10,380,117,533])
set_param([sys,'/',['Double click',13,'on this for demo.2']],...
		'Mask Display','MODELISATION AVEC COMMANDE MAGNETO-COUPLEURS PAR LA DERIVEE DU CHAMP MAGNETIQUE TERRESTRE',...
		'Mask Type','',...
		'Mask Dialogue',' ',...
		'Mask Translate','')
set_param([sys,'/',['Double click',13,'on this for demo.2']],...
		'Mask Help','')


%     Finished composite block ['Double click',13,'on this for demo.2'].

set_param([sys,'/',['Double click',13,'on this for demo.2']],...
		'ForeGround',2,...
		'BackGround',3,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',10,...
		'position',[20,10,610,56])

add_block('built-in/Sum',[sys,'/','Sum'])
set_param([sys,'/','Sum'],...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',10,...
		'position',[305,200,325,240])

add_block('built-in/Note',[sys,'/','Sign:GUIZIOU 1994//95'])
set_param([sys,'/','Sign:GUIZIOU 1994//95'],...
		'ForeGround',5,...
		'Font Name','Arial',...
		'Font Size',10,...
		'position',[525,60,526,61])

add_block('built-in/To File',[sys,'/','To File'])
set_param([sys,'/','To File'],...
		'orientation',2,...
		'ForeGround',1,...
		'BackGround',4,...
		'Font Size',10,...
		'File name','res_derx.mat',...
		'Matrix name','simux',...
		'position',[345,367,445,403])


%     Subsystem  'UnNamed'.

new_system([sys,'/','UnNamed'])
set_param([sys,'/','UnNamed'],'Location',[50,5439615,480,5439810])

add_block('built-in/Constant',[sys,'/','UnNamed/Constant3'])
set_param([sys,'/','UnNamed/Constant3'],...
		'hide name',0,...
		'Value','rayon_orbital',...
		'position',[65,129,155,161])

add_block('built-in/Constant',[sys,'/','UnNamed/Constant2'])
set_param([sys,'/','UnNamed/Constant2'],...
		'hide name',0,...
		'Value','inclinaison',...
		'position',[65,89,155,121])

add_block('built-in/MATLAB Fcn',[sys,'/','UnNamed/MATLAB Fcn'])
set_param([sys,'/','UnNamed/MATLAB Fcn'],...
		'MATLAB Fcn','champmgn(u)',...
		'position',[270,77,395,133])

add_block('built-in/Clock',[sys,'/','UnNamed/Clock'])
set_param([sys,'/','UnNamed/Clock'],...
		'position',[65,55,85,75])

add_block('built-in/Mux',[sys,'/','UnNamed/Mux'])
set_param([sys,'/','UnNamed/Mux'],...
		'inputs','3',...
		'position',[210,48,250,162])

add_block('built-in/Note',[sys,'/','UnNamed/Temps'])
set_param([sys,'/','UnNamed/Temps'],...
		'position',[125,50,126,51])

add_block('built-in/Outport',[sys,'/','UnNamed/out_1'])
set_param([sys,'/','UnNamed/out_1'],...
		'position',[415,95,435,115])
add_line([sys,'/','UnNamed'],[255,105;260,105])
add_line([sys,'/','UnNamed'],[160,145;200,145])
add_line([sys,'/','UnNamed'],[90,65;200,65])
add_line([sys,'/','UnNamed'],[160,105;200,105])
add_line([sys,'/','UnNamed'],[400,105;405,105])
set_param([sys,'/','UnNamed'],...
		'Mask Display','CHAMP TERRESTRE\nEN REPERE ORBITAL')


%     Finished composite block 'UnNamed'.

set_param([sys,'/','UnNamed'],...
		'orientation',2,...
		'hide name',0,...
		'position',[520,270,635,320])

add_block('built-in/Note',[sys,'/',' TANGAGE ET ROULIS'])
set_param([sys,'/',' TANGAGE ET ROULIS'],...
		'ForeGround',3,...
		'Font Name','Arial',...
		'Font Size',10,...
		'position',[575,90,576,91])

add_block('built-in/Scope',[sys,'/','Scope1'])
set_param([sys,'/','Scope1'],...
		'BackGround',3,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',10,...
		'Vgain','0.150000',...
		'Hgain','40000.000000',...
		'Vmax','0.300000',...
		'Hmax','80000.000000')
set_param([sys,'/','Scope1'],...
		'Window',[0,42,623,259])
open_system([sys,'/','Scope1'])
set_param([sys,'/','Scope1'],...
		'position',[600,114,640,156])

add_block('built-in/Mux',[sys,'/','Mux'])
set_param([sys,'/','Mux'],...
		'BackGround',3,...
		'inputs','2',...
		'position',[555,115,580,155])

add_block('built-in/Demux',[sys,'/','Demux1'])
set_param([sys,'/','Demux1'],...
		'BackGround',3,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',10,...
		'outputs','6',...
		'position',[510,119,530,181])

add_block('built-in/Scope',[sys,'/','Scope'])
set_param([sys,'/','Scope'],...
		'BackGround',5,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',10,...
		'Vgain','1.000000',...
		'Hgain','40000.000000',...
		'Vmax','2.000000',...
		'Hmax','80000.000000')
set_param([sys,'/','Scope'],...
		'Window',[0,256,623,473])
open_system([sys,'/','Scope'])
set_param([sys,'/','Scope'],...
		'position',[580,339,620,381])


%     Subsystem  ['Variables',13,'de commande'].

new_system([sys,'/',['Variables',13,'de commande']])
set_param([sys,'/',['Variables',13,'de commande']],'Location',[4,42,628,468])

add_block('built-in/To Workspace',[sys,'/',['Variables',13,'de commande/To Workspace2']])
set_param([sys,'/',['Variables',13,'de commande/To Workspace2']],...
		'hide name',0,...
		'mat-name','commande_z',...
		'buffer','points_trace',...
		'position',[135,136,215,154])

add_block('built-in/To Workspace',[sys,'/',['Variables',13,'de commande/To Workspace1']])
set_param([sys,'/',['Variables',13,'de commande/To Workspace1']],...
		'hide name',0,...
		'mat-name','commande_y',...
		'buffer','points_trace',...
		'position',[135,106,215,124])

add_block('built-in/Demux',[sys,'/',['Variables',13,'de commande/Demux']])
set_param([sys,'/',['Variables',13,'de commande/Demux']],...
		'hide name',0,...
		'outputs','3',...
		'position',[65,67,105,163])

add_block('built-in/To Workspace',[sys,'/',['Variables',13,'de commande/To Workspace']])
set_param([sys,'/',['Variables',13,'de commande/To Workspace']],...
		'hide name',0,...
		'mat-name','commande_x',...
		'buffer','points_trace',...
		'position',[135,76,215,94])

add_block('built-in/Inport',[sys,'/',['Variables',13,'de commande/in_1']])
set_param([sys,'/',['Variables',13,'de commande/in_1']],...
		'position',[15,105,35,125])
add_line([sys,'/',['Variables',13,'de commande']],[110,145;125,145])
add_line([sys,'/',['Variables',13,'de commande']],[110,115;125,115])
add_line([sys,'/',['Variables',13,'de commande']],[110,85;125,85])
add_line([sys,'/',['Variables',13,'de commande']],[40,115;55,115])
set_param([sys,'/',['Variables',13,'de commande']],...
		'Mask Display','Commande\nde couple\nsur les trois axes')


%     Finished composite block ['Variables',13,'de commande'].

set_param([sys,'/',['Variables',13,'de commande']],...
		'ForeGround',1,...
		'BackGround',4,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',10,...
		'position',[330,129,435,191])

add_block('built-in/Clock',[sys,'/','Clock'])
set_param([sys,'/','Clock'],...
		'ForeGround',3,...
		'BackGround',6,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',10,...
		'position',[370,100,390,120])

add_block('built-in/To Workspace',[sys,'/','To Workspace'])
set_param([sys,'/','To Workspace'],...
		'ForeGround',3,...
		'BackGround',6,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',10,...
		'mat-name','temps',...
		'buffer','points_trace',...
		'position',[435,102,485,118])

add_block('built-in/Demux',[sys,'/','Demux'])
set_param([sys,'/','Demux'],...
		'BackGround',5,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',10,...
		'outputs','6',...
		'position',[525,333,555,372])


%     Subsystem  ['Calcul champ magntique',13,'terrestre'].

new_system([sys,'/',['Calcul champ magntique',13,'terrestre']])
set_param([sys,'/',['Calcul champ magntique',13,'terrestre']],'Location',[4,42,628,468])

add_block('built-in/Inport',[sys,'/',['Calcul champ magntique',13,'terrestre/in_2']])
set_param([sys,'/',['Calcul champ magntique',13,'terrestre/in_2']],...
		'Port','2',...
		'position',[10,160,30,180])

add_block('built-in/Note',[sys,'/',['Calcul champ magntique',13,'terrestre/Vecteur',13,'d''tat']])
set_param([sys,'/',['Calcul champ magntique',13,'terrestre/Vecteur',13,'d''tat']],...
		'position',[53,140,54,141])

add_block('built-in/Inport',[sys,'/',['Calcul champ magntique',13,'terrestre/in_1']])
set_param([sys,'/',['Calcul champ magntique',13,'terrestre/in_1']],...
		'position',[10,115,30,135])

add_block('built-in/Note',[sys,'/',['Calcul champ magntique',13,'terrestre/Champ magntique',13,'terrestre',13,'(repre orbital)']])
set_param([sys,'/',['Calcul champ magntique',13,'terrestre/Champ magntique',13,'terrestre',13,'(repre orbital)']],...
		'position',[100,80,101,81])

add_block('built-in/Mux',[sys,'/',['Calcul champ magntique',13,'terrestre/Mux4']])
set_param([sys,'/',['Calcul champ magntique',13,'terrestre/Mux4']],...
		'hide name',0,...
		'inputs','[3 3]',...
		'position',[165,100,200,195])

add_block('built-in/State-space',[sys,'/',['Calcul champ magntique',13,'terrestre/Matrix gain.4']])
set_param([sys,'/',['Calcul champ magntique',13,'terrestre/Matrix gain.4']],...
		'A','[]',...
		'B','[]',...
		'C','[]',...
		'D','K',...
		'Mask Display','matrice',...
		'Mask Type','Matrix gain')
set_param([sys,'/',['Calcul champ magntique',13,'terrestre/Matrix gain.4']],...
		'Mask Dialogue','Matrix Gain:|Gain matrix:',...
		'Mask Translate','K = @1;',...
		'Mask Help','Multiplies input vector by entered matrix to produce output vector.')
set_param([sys,'/',['Calcul champ magntique',13,'terrestre/Matrix gain.4']],...
		'Mask Entries','[1 0 0 0 0 0;0 0 1 0 0 0 ;0 0 0 0 1 0]\/',...
		'position',[75,153,130,187])

add_block('built-in/Note',[sys,'/',['Calcul champ magntique',13,'terrestre/Champ magntique',13,'terrestre',13,'(repre satellite)']])
set_param([sys,'/',['Calcul champ magntique',13,'terrestre/Champ magntique',13,'terrestre',13,'(repre satellite)']],...
		'position',[471,135,472,136])

add_block('built-in/Outport',[sys,'/',['Calcul champ magntique',13,'terrestre/out_1']])
set_param([sys,'/',['Calcul champ magntique',13,'terrestre/out_1']],...
		'Mask Display','',...
		'position',[390,140,410,160])

add_block('built-in/MATLAB Fcn',[sys,'/',['Calcul champ magntique',13,'terrestre/MATLAB Fcn']])
set_param([sys,'/',['Calcul champ magntique',13,'terrestre/MATLAB Fcn']],...
		'hide name',0,...
		'MATLAB Fcn','passage(u)',...
		'Output Width','3',...
		'Mask Display','CHANGEMENT\nDE BASE',...
		'position',[245,127,345,173])
add_line([sys,'/',['Calcul champ magntique',13,'terrestre']],[35,125;155,125])
add_line([sys,'/',['Calcul champ magntique',13,'terrestre']],[35,170;65,170])
add_line([sys,'/',['Calcul champ magntique',13,'terrestre']],[135,170;155,170])
add_line([sys,'/',['Calcul champ magntique',13,'terrestre']],[205,150;235,150])
add_line([sys,'/',['Calcul champ magntique',13,'terrestre']],[350,150;380,150])
set_param([sys,'/',['Calcul champ magntique',13,'terrestre']],...
		'Mask Display','Calcul du champ\nmagntique terrestre\n(repre satellite)')


%     Finished composite block ['Calcul champ magntique',13,'terrestre'].

set_param([sys,'/',['Calcul champ magntique',13,'terrestre']],...
		'orientation',2,...
		'BackGround',7,...
		'Font Name','Arial',...
		'Font Size',10,...
		'position',[345,280,480,335])

add_block('built-in/Discrete State-space',[sys,'/','Modle discrtis'])
set_param([sys,'/','Modle discrtis'],...
		'ForeGround',1,...
		'BackGround',2,...
		'hide name',0,...
		'A','Asat_d',...
		'B','Bsat_d',...
		'C','eye(Asat_d)',...
		'D','zeros(Bsat_d)',...
		'X0','[0.1 0 0.1 0 0.05 -0.001]''')
set_param([sys,'/','Modle discrtis'],...
		'Sample time','temps_echant',...
		'position',[360,196,480,244])


%     Subsystem  'UnNamed1'.

new_system([sys,'/','UnNamed1'])
set_param([sys,'/','UnNamed1'],'Location',[4,42,628,468])

add_block('built-in/Inport',[sys,'/','UnNamed1/in_1'])
set_param([sys,'/','UnNamed1/in_1'],...
		'position',[15,130,35,150])

add_block('built-in/To Workspace',[sys,'/','UnNamed1/To Workspace'])
set_param([sys,'/','UnNamed1/To Workspace'],...
		'hide name',0,...
		'mat-name','roulis',...
		'buffer','points_trace',...
		'position',[165,67,215,83])

add_block('built-in/Demux',[sys,'/','UnNamed1/Demux'])
set_param([sys,'/','UnNamed1/Demux'],...
		'hide name',0,...
		'outputs','6',...
		'position',[65,59,105,216])

add_block('built-in/To Workspace',[sys,'/','UnNamed1/To Workspace1'])
set_param([sys,'/','UnNamed1/To Workspace1'],...
		'hide name',0,...
		'mat-name','v_roulis',...
		'buffer','points_trace',...
		'position',[165,92,215,108])

add_block('built-in/To Workspace',[sys,'/','UnNamed1/To Workspace2'])
set_param([sys,'/','UnNamed1/To Workspace2'],...
		'hide name',0,...
		'mat-name','tangage',...
		'buffer','points_trace',...
		'position',[165,117,215,133])

add_block('built-in/To Workspace',[sys,'/','UnNamed1/To Workspace3'])
set_param([sys,'/','UnNamed1/To Workspace3'],...
		'hide name',0,...
		'mat-name','v_tangage',...
		'buffer','points_trace',...
		'position',[165,142,215,158])

add_block('built-in/To Workspace',[sys,'/','UnNamed1/To Workspace4'])
set_param([sys,'/','UnNamed1/To Workspace4'],...
		'hide name',0,...
		'mat-name','lacet',...
		'buffer','points_trace',...
		'position',[165,167,215,183])

add_block('built-in/To Workspace',[sys,'/','UnNamed1/To Workspace5'])
set_param([sys,'/','UnNamed1/To Workspace5'],...
		'hide name',0,...
		'mat-name','v_lacet',...
		'buffer','points_trace',...
		'position',[165,192,215,208])
add_line([sys,'/','UnNamed1'],[40,140;55,140])
add_line([sys,'/','UnNamed1'],[110,75;155,75])
add_line([sys,'/','UnNamed1'],[110,100;155,100])
add_line([sys,'/','UnNamed1'],[110,125;155,125])
add_line([sys,'/','UnNamed1'],[110,150;155,150])
add_line([sys,'/','UnNamed1'],[110,175;155,175])
add_line([sys,'/','UnNamed1'],[110,200;155,200])
set_param([sys,'/','UnNamed1'],...
		'Mask Display','Sortie\nsystme\n(angles et\nvitesses angulaires)')


%     Finished composite block 'UnNamed1'.

set_param([sys,'/','UnNamed1'],...
		'ForeGround',1,...
		'BackGround',4,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',10,...
		'position',[510,189,615,251])
add_line(sys,[160,215;165,215])
add_line(sys,[90,210;125,210])
add_line(sys,[515,295;490,295])
add_line(sys,[395,110;425,110])
add_line(sys,[130,120;160,120])
add_line(sys,[210,120;285,120;285,210;295,210])
add_line(sys,[265,230;295,230])
add_line(sys,[275,230;275,160;320,160])
add_line(sys,[485,220;500,220])
add_line(sys,[340,310;300,310;300,285;130,285;130,240;165,240])
add_line(sys,[300,310;285,310])
add_line(sys,[215,310;200,310])
add_line(sys,[500,220;500,320;490,320])
add_line(sys,[150,310;105,310;105,220;125,220])
add_line(sys,[140,310;140,340;130,340])
add_line(sys,[500,320;500,355;515,355])
add_line(sys,[500,355;505,355;505,385;455,385])
add_line(sys,[500,220;500,150])
add_line(sys,[560,360;570,360])
add_line(sys,[585,135;590,135])
add_line(sys,[535,125;545,125])
add_line(sys,[535,145;545,145])
add_line(sys,[330,220;350,220])

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str] = feval(sys);
	end
end
