function [ret,x0,str]=scaoderz(t,x,u,flag);
%SCAODERZ	is the M-file description of the SIMULINK system named SCAODERZ.
%	The block-diagram can be displayed by typing: SCAODERZ.
%
%	SYS=SCAODERZ(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes SCAODERZ to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling SCAODERZ with a FLAG of zero:
%	[SIZES]=SCAODERZ([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs.
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.2)
if(0 == (nargin + nargout))
     set_param(sys,'Location',[4,42,627,468])
     open_system(sys)
end;
set_param(sys,'BackGround',0)
set_param(sys,'algorithm',		'Linear')
set_param(sys,'Start time',	'0.0')
set_param(sys,'Stop time',		'tsim')
set_param(sys,'Min step size',	'tsim/1000')
set_param(sys,'Max step size',	'tsim/500')
set_param(sys,'Relative error','1e-3')
set_param(sys,'Return vars',	'')

add_block('built-in/Note',[sys,'/','M'])
set_param([sys,'/','M'],...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',10,...
		'position',[162,190,163,191])

add_block('built-in/Note',[sys,'/','Mc'])
set_param([sys,'/','Mc'],...
		'Font Name','Arial',...
		'Font Size',10,...
		'position',[280,230,281,231])


%     Subsystem  'UnNamed4'.

new_system([sys,'/','UnNamed4'])
set_param([sys,'/','UnNamed4'],'Location',[4,61,260,242])

add_block('built-in/Outport',[sys,'/','UnNamed4/out_1'])
set_param([sys,'/','UnNamed4/out_1'],...
		'position',[235,85,255,105])

add_block('built-in/Mux',[sys,'/','UnNamed4/Mux'])
set_param([sys,'/','UnNamed4/Mux'],...
		'inputs','3',...
		'position',[150,57,180,133])

add_block('built-in/Constant',[sys,'/','UnNamed4/Constant1'])
set_param([sys,'/','UnNamed4/Constant1'],...
		'hide name',0,...
		'Value','0',...
		'position',[65,60,85,80])

add_block('built-in/Constant',[sys,'/','UnNamed4/Constant2'])
set_param([sys,'/','UnNamed4/Constant2'],...
		'hide name',0,...
		'Value','0',...
		'position',[65,85,85,105])

add_block('built-in/Constant',[sys,'/','UnNamed4/Constant3'])
set_param([sys,'/','UnNamed4/Constant3'],...
		'hide name',0,...
		'Value','0',...
		'position',[65,110,85,130])
add_line([sys,'/','UnNamed4'],[90,70;140,70])
add_line([sys,'/','UnNamed4'],[90,95;140,95])
add_line([sys,'/','UnNamed4'],[90,120;140,120])
add_line([sys,'/','UnNamed4'],[185,95;225,95])
set_param([sys,'/','UnNamed4'],...
		'Mask Display','Consigne\nnulle')


%     Finished composite block 'UnNamed4'.

set_param([sys,'/','UnNamed4'],...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',10,...
		'position',[25,190,85,230])

add_block('built-in/Sum',[sys,'/','Sum1'])
set_param([sys,'/','Sum1'],...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',10,...
		'inputs','+-',...
		'position',[135,205,155,225])


%     Subsystem  ['Double click',13,'on this for demo.2'].

new_system([sys,'/',['Double click',13,'on this for demo.2']])
set_param([sys,'/',['Double click',13,'on this for demo.2']],'Location',[-10,380,117,533])
set_param([sys,'/',['Double click',13,'on this for demo.2']],...
		'Mask Display','MODELISATION AVEC COMMANDE MAGNETO-COUPLEURS PAR L''ERREUR SUR LE MOMENT CINETIQUE\n (Avec majoration de gain sur la chane lacet)',...
		'Mask Type','')
set_param([sys,'/',['Double click',13,'on this for demo.2']],...
		'Mask Dialogue',' ',...
		'Mask Translate','',...
		'Mask Help','')


%     Finished composite block ['Double click',13,'on this for demo.2'].

set_param([sys,'/',['Double click',13,'on this for demo.2']],...
		'ForeGround',2,...
		'BackGround',3,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',10,...
		'position',[20,10,610,56])

add_block('built-in/Sum',[sys,'/','Sum'])
set_param([sys,'/','Sum'],...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',10,...
		'position',[305,200,325,240])

add_block('built-in/Note',[sys,'/','Sign:GUIZIOU 1994//95'])
set_param([sys,'/','Sign:GUIZIOU 1994//95'],...
		'ForeGround',5,...
		'Font Name','Arial',...
		'Font Size',10,...
		'position',[525,60,526,61])

add_block('built-in/Note',[sys,'/','B'])
set_param([sys,'/','B'],...
		'Font Name','Arial',...
		'Font Size',10,...
		'position',[311,290,312,291])

add_block('built-in/Note',[sys,'/','Brel'])
set_param([sys,'/','Brel'],...
		'ForeGround',5,...
		'Font Name','Arial',...
		'Font Size',10,...
		'position',[280,250,281,251])


%     Subsystem  ['Variables',13,'de commande1'].

new_system([sys,'/',['Variables',13,'de commande1']])
set_param([sys,'/',['Variables',13,'de commande1']],'Location',[4,42,628,468])

add_block('built-in/Inport',[sys,'/',['Variables',13,'de commande1/in_1']])
set_param([sys,'/',['Variables',13,'de commande1/in_1']],...
		'position',[15,105,35,125])

add_block('built-in/To Workspace',[sys,'/',['Variables',13,'de commande1/To Workspace']])
set_param([sys,'/',['Variables',13,'de commande1/To Workspace']],...
		'hide name',0,...
		'mat-name','mx',...
		'buffer','points_trace',...
		'position',[135,76,215,94])

add_block('built-in/Demux',[sys,'/',['Variables',13,'de commande1/Demux']])
set_param([sys,'/',['Variables',13,'de commande1/Demux']],...
		'hide name',0,...
		'outputs','3',...
		'position',[65,67,105,163])

add_block('built-in/To Workspace',[sys,'/',['Variables',13,'de commande1/To Workspace1']])
set_param([sys,'/',['Variables',13,'de commande1/To Workspace1']],...
		'hide name',0,...
		'mat-name','my',...
		'buffer','points_trace',...
		'position',[135,106,215,124])

add_block('built-in/To Workspace',[sys,'/',['Variables',13,'de commande1/To Workspace2']])
set_param([sys,'/',['Variables',13,'de commande1/To Workspace2']],...
		'hide name',0,...
		'mat-name','mz',...
		'buffer','points_trace',...
		'position',[135,136,215,154])
add_line([sys,'/',['Variables',13,'de commande1']],[40,115;55,115])
add_line([sys,'/',['Variables',13,'de commande1']],[110,85;125,85])
add_line([sys,'/',['Variables',13,'de commande1']],[110,115;125,115])
add_line([sys,'/',['Variables',13,'de commande1']],[110,145;125,145])
set_param([sys,'/',['Variables',13,'de commande1']],...
		'Mask Display','MOMENT\nMAGNETIQUE')


%     Finished composite block ['Variables',13,'de commande1'].

set_param([sys,'/',['Variables',13,'de commande1']],...
		'ForeGround',1,...
		'BackGround',4,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',10,...
		'position',[165,152,245,188])


%     Subsystem  'INERTIES REGLABLES'.

new_system([sys,'/','INERTIES REGLABLES'])
set_param([sys,'/','INERTIES REGLABLES'],'Location',[4,42,628,468])

add_block('built-in/Mux',[sys,'/','INERTIES REGLABLES/Mux4'])
set_param([sys,'/','INERTIES REGLABLES/Mux4'],...
		'hide name',0,...
		'inputs','[3 3]',...
		'position',[190,65,225,160])

add_block('built-in/MATLAB Fcn',[sys,'/','INERTIES REGLABLES/MATLAB Fcn'])
set_param([sys,'/','INERTIES REGLABLES/MATLAB Fcn'],...
		'hide name',0,...
		'MATLAB Fcn','cross(u(1:3),u(4:6))',...
		'Output Width','3',...
		'Mask Display','MOMENT MAGNETIQUE\nH x B en axes satellite',...
		'position',[250,91,360,139])

add_block('built-in/State-space',[sys,'/','INERTIES REGLABLES/Matrix gain.4'])
set_param([sys,'/','INERTIES REGLABLES/Matrix gain.4'],...
		'hide name',0,...
		'A','[]',...
		'B','[]',...
		'C','[]',...
		'D','K',...
		'Mask Display','Moment cinetique\nrsiduel',...
		'Mask Type','Matrix gain')
set_param([sys,'/','INERTIES REGLABLES/Matrix gain.4'],...
		'Mask Dialogue','Matrix Gain:|Gain matrix:',...
		'Mask Translate','K = @1;',...
		'Mask Help','Multiplies input vector by entered matrix to produce output vector.')
set_param([sys,'/','INERTIES REGLABLES/Matrix gain.4'],...
		'Mask Entries','[0 Ir 0 0 0 0;0 0 0 It 0 0 ;0 0 0 0 0 100*Il]\/',...
		'position',[90,116,165,154])

add_block('built-in/Note',[sys,'/',['INERTIES REGLABLES/Vecteur',13,'d''tat']])
set_param([sys,'/',['INERTIES REGLABLES/Vecteur',13,'d''tat']],...
		'position',[63,105,64,106])

add_block('built-in/Note',[sys,'/',['INERTIES REGLABLES/Champ magntique',13,'terrestre',13,'(repre orbital)']])
set_param([sys,'/',['INERTIES REGLABLES/Champ magntique',13,'terrestre',13,'(repre orbital)']],...
		'position',[110,50,111,51])

add_block('built-in/Inport',[sys,'/','INERTIES REGLABLES/in_1'])
set_param([sys,'/','INERTIES REGLABLES/in_1'],...
		'position',[15,80,35,100])

add_block('built-in/Inport',[sys,'/','INERTIES REGLABLES/in_2'])
set_param([sys,'/','INERTIES REGLABLES/in_2'],...
		'Port','2',...
		'position',[15,125,35,145])

add_block('built-in/Outport',[sys,'/','INERTIES REGLABLES/out_1'])
set_param([sys,'/','INERTIES REGLABLES/out_1'],...
		'position',[480,105,500,125])
add_line([sys,'/','INERTIES REGLABLES'],[230,115;240,115])
add_line([sys,'/','INERTIES REGLABLES'],[170,135;180,135])
add_line([sys,'/','INERTIES REGLABLES'],[40,90;180,90])
add_line([sys,'/','INERTIES REGLABLES'],[365,115;470,115])
add_line([sys,'/','INERTIES REGLABLES'],[40,135;80,135])
set_param([sys,'/','INERTIES REGLABLES'],...
		'Mask Display','COMMANDE PAR LE\nMOMENT CINETIQUE\nRESIDUEL')


%     Finished composite block 'INERTIES REGLABLES'.

set_param([sys,'/','INERTIES REGLABLES'],...
		'orientation',2,...
		'BackGround',6,...
		'position',[175,274,270,336])


%     Subsystem  ['Calcul couples',13,'de commande'].

new_system([sys,'/',['Calcul couples',13,'de commande']])
set_param([sys,'/',['Calcul couples',13,'de commande']],'Location',[4,42,628,468])

add_block('built-in/Note',[sys,'/',['Calcul couples',13,'de commande/CALCUL DU COUPLE DE COMMANDE POUR  UNE COMMANDE',13,' PAR  LA DERIVEE DU CHAMP MAGNETIQUE']])
set_param([sys,'/',['Calcul couples',13,'de commande/CALCUL DU COUPLE DE COMMANDE POUR  UNE COMMANDE',13,' PAR  LA DERIVEE DU CHAMP MAGNETIQUE']],...
		'ForeGround',2,...
		'Font Name','Arial',...
		'Font Size',16)
set_param([sys,'/',['Calcul couples',13,'de commande/CALCUL DU COUPLE DE COMMANDE POUR  UNE COMMANDE',13,' PAR  LA DERIVEE DU CHAMP MAGNETIQUE']],...
		'position',[320,15,321,16])

add_block('built-in/Inport',[sys,'/',['Calcul couples',13,'de commande/in_4']])
set_param([sys,'/',['Calcul couples',13,'de commande/in_4']],...
		'Port','2',...
		'position',[35,160,55,180])

add_block('built-in/Inport',[sys,'/',['Calcul couples',13,'de commande/in_3']])
set_param([sys,'/',['Calcul couples',13,'de commande/in_3']],...
		'position',[35,125,55,145])

add_block('built-in/Mux',[sys,'/',['Calcul couples',13,'de commande/Mux1']])
set_param([sys,'/',['Calcul couples',13,'de commande/Mux1']],...
		'hide name',0,...
		'inputs','[3 3]',...
		'position',[90,115,130,190])

add_block('built-in/MATLAB Fcn',[sys,'/',['Calcul couples',13,'de commande/MATLAB Fcn1']])
set_param([sys,'/',['Calcul couples',13,'de commande/MATLAB Fcn1']],...
		'hide name',0,...
		'MATLAB Fcn','cross(u(1:3),u(4:6))',...
		'Output Width','3',...
		'position',[155,135,250,175])

add_block('built-in/Demux',[sys,'/',['Calcul couples',13,'de commande/Demux']])
set_param([sys,'/',['Calcul couples',13,'de commande/Demux']],...
		'outputs','3',...
		'position',[295,122,325,188])

add_block('built-in/Unit Delay',[sys,'/',['Calcul couples',13,'de commande/Unit Delay']])
set_param([sys,'/',['Calcul couples',13,'de commande/Unit Delay']],...
		'Sample time','temps_echant',...
		'position',[360,127,410,143])

add_block('built-in/Unit Delay',[sys,'/',['Calcul couples',13,'de commande/Unit Delay2']])
set_param([sys,'/',['Calcul couples',13,'de commande/Unit Delay2']],...
		'Sample time','temps_echant',...
		'position',[360,147,410,163])

add_block('built-in/Unit Delay',[sys,'/',['Calcul couples',13,'de commande/Unit Delay1']])
set_param([sys,'/',['Calcul couples',13,'de commande/Unit Delay1']],...
		'Sample time','temps_echant',...
		'position',[360,167,410,183])

add_block('built-in/Mux',[sys,'/',['Calcul couples',13,'de commande/Mux']])
set_param([sys,'/',['Calcul couples',13,'de commande/Mux']],...
		'inputs','3',...
		'position',[455,122,485,188])

add_block('built-in/Outport',[sys,'/',['Calcul couples',13,'de commande/out_2']])
set_param([sys,'/',['Calcul couples',13,'de commande/out_2']],...
		'position',[520,145,540,165])

add_block('built-in/Note',[sys,'/',['Calcul couples',13,'de commande/ECHANTILLONNAGE A 5 SECONDES ']])
set_param([sys,'/',['Calcul couples',13,'de commande/ECHANTILLONNAGE A 5 SECONDES ']],...
		'position',[305,75,306,76])
add_line([sys,'/',['Calcul couples',13,'de commande']],[135,155;145,155])
add_line([sys,'/',['Calcul couples',13,'de commande']],[60,135;80,135])
add_line([sys,'/',['Calcul couples',13,'de commande']],[255,155;285,155])
add_line([sys,'/',['Calcul couples',13,'de commande']],[60,170;80,170])
add_line([sys,'/',['Calcul couples',13,'de commande']],[490,155;510,155])
add_line([sys,'/',['Calcul couples',13,'de commande']],[330,175;350,175])
add_line([sys,'/',['Calcul couples',13,'de commande']],[415,175;445,175])
add_line([sys,'/',['Calcul couples',13,'de commande']],[330,155;350,155])
add_line([sys,'/',['Calcul couples',13,'de commande']],[415,155;445,155])
add_line([sys,'/',['Calcul couples',13,'de commande']],[330,135;350,135])
add_line([sys,'/',['Calcul couples',13,'de commande']],[415,135;445,135])
set_param([sys,'/',['Calcul couples',13,'de commande']],...
		'Mask Display','Calcul\ndu couple\nde contrle Mc')


%     Finished composite block ['Calcul couples',13,'de commande'].

set_param([sys,'/',['Calcul couples',13,'de commande']],...
		'BackGround',7,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',10,...
		'position',[180,200,265,255])

add_block('built-in/Note',[sys,'/',['IL FAUT FIXER LES SEUILS DE SATURATION DES MAGNETOCOUPLEURS',13,'']])
set_param([sys,'/',['IL FAUT FIXER LES SEUILS DE SATURATION DES MAGNETOCOUPLEURS',13,'']],...
		'ForeGround',5,...
		'Font Size',14,...
		'position',[315,390,316,391])


%     Subsystem  'MAGNETOCOUPLEURS'.

new_system([sys,'/','MAGNETOCOUPLEURS'])
set_param([sys,'/','MAGNETOCOUPLEURS'],'Location',[4,42,628,468])

add_block('built-in/Mux',[sys,'/','MAGNETOCOUPLEURS/Mux1'])
set_param([sys,'/','MAGNETOCOUPLEURS/Mux1'],...
		'inputs','3',...
		'position',[365,161,400,279])

add_block('built-in/Unit Delay',[sys,'/','MAGNETOCOUPLEURS/Unit Delay1'])
set_param([sys,'/','MAGNETOCOUPLEURS/Unit Delay1'],...
		'Sample time','temps_echant_magn',...
		'position',[270,252,320,268])

add_block('built-in/Unit Delay',[sys,'/','MAGNETOCOUPLEURS/Unit Delay2'])
set_param([sys,'/','MAGNETOCOUPLEURS/Unit Delay2'],...
		'Sample time','temps_echant_magn',...
		'position',[270,212,320,228])

add_block('built-in/Inport',[sys,'/','MAGNETOCOUPLEURS/in_1'])
set_param([sys,'/','MAGNETOCOUPLEURS/in_1'],...
		'position',[60,210,80,230])

add_block('built-in/Saturation',[sys,'/','MAGNETOCOUPLEURS/Saturation'])
set_param([sys,'/','MAGNETOCOUPLEURS/Saturation'],...
		'hide name',0,...
		'Lower Limit','-seuil_sat*ones(1,3)',...
		'Upper Limit','seuil_sat*ones(1,3)',...
		'position',[180,202,220,238])

add_block('built-in/Saturation',[sys,'/','MAGNETOCOUPLEURS/Saturation1'])
set_param([sys,'/','MAGNETOCOUPLEURS/Saturation1'],...
		'hide name',0,...
		'Lower Limit','-seuil_sat*ones(1,3)',...
		'Upper Limit','seuil_sat*ones(1,3)',...
		'position',[180,242,220,278])

add_block('built-in/Saturation',[sys,'/','MAGNETOCOUPLEURS/Saturation2'])
set_param([sys,'/','MAGNETOCOUPLEURS/Saturation2'],...
		'hide name',0,...
		'Lower Limit','-seuil_sat*ones(1,3)',...
		'Upper Limit','seuil_sat*ones(1,3)',...
		'position',[180,162,220,198])

add_block('built-in/Demux',[sys,'/','MAGNETOCOUPLEURS/Demux'])
set_param([sys,'/','MAGNETOCOUPLEURS/Demux'],...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',10,...
		'outputs','3',...
		'position',[110,159,145,281])

add_block('built-in/Unit Delay',[sys,'/','MAGNETOCOUPLEURS/Unit Delay'])
set_param([sys,'/','MAGNETOCOUPLEURS/Unit Delay'],...
		'Sample time','temps_echant_magn',...
		'position',[270,172,320,188])

add_block('built-in/Sum',[sys,'/','MAGNETOCOUPLEURS/Sum'])
set_param([sys,'/','MAGNETOCOUPLEURS/Sum'],...
		'position',[500,205,520,225])

add_block('built-in/Outport',[sys,'/','MAGNETOCOUPLEURS/out_1'])
set_param([sys,'/','MAGNETOCOUPLEURS/out_1'],...
		'position',[565,205,585,225])

add_block('built-in/Constant',[sys,'/','MAGNETOCOUPLEURS/Constant'])
set_param([sys,'/','MAGNETOCOUPLEURS/Constant'],...
		'Value','[1 1 1]*biais_magneto',...
		'Mask Display','BIAIS\nMAGBNETOCOUPLEURS',...
		'position',[345,103,415,137])

add_block('built-in/Note',[sys,'/',['MAGNETOCOUPLEURS/MODELE DE MAGNETOCOUPLEURS ECHANTILLONNES',13,', BIAISES, BRUITES AVEC SEUIL DE SATURATION']])
set_param([sys,'/',['MAGNETOCOUPLEURS/MODELE DE MAGNETOCOUPLEURS ECHANTILLONNES',13,', BIAISES, BRUITES AVEC SEUIL DE SATURATION']],...
		'Font Name','Arial',...
		'Font Size',16,...
		'position',[320,30,321,31])
add_line([sys,'/','MAGNETOCOUPLEURS'],[150,260;170,260])
add_line([sys,'/','MAGNETOCOUPLEURS'],[150,220;170,220])
add_line([sys,'/','MAGNETOCOUPLEURS'],[150,180;170,180])
add_line([sys,'/','MAGNETOCOUPLEURS'],[85,220;100,220])
add_line([sys,'/','MAGNETOCOUPLEURS'],[325,260;355,260])
add_line([sys,'/','MAGNETOCOUPLEURS'],[325,220;355,220])
add_line([sys,'/','MAGNETOCOUPLEURS'],[325,180;355,180])
add_line([sys,'/','MAGNETOCOUPLEURS'],[225,180;260,180])
add_line([sys,'/','MAGNETOCOUPLEURS'],[225,220;260,220])
add_line([sys,'/','MAGNETOCOUPLEURS'],[225,260;260,260])
add_line([sys,'/','MAGNETOCOUPLEURS'],[525,215;555,215])
add_line([sys,'/','MAGNETOCOUPLEURS'],[405,220;490,220])
add_line([sys,'/','MAGNETOCOUPLEURS'],[420,120;450,120;450,210;490,210])
set_param([sys,'/','MAGNETOCOUPLEURS'],...
		'Mask Display','MODELE MAGNETO\nSATURATION\n+ECHANT')


%     Finished composite block 'MAGNETOCOUPLEURS'.

set_param([sys,'/','MAGNETOCOUPLEURS'],...
		'orientation',3,...
		'BackGround',7,...
		'move name',0,...
		'position',[44,240,136,285])


%     Subsystem  ['Perturbations',13,'arodynamiques'].

new_system([sys,'/',['Perturbations',13,'arodynamiques']])
set_param([sys,'/',['Perturbations',13,'arodynamiques']],'Location',[4,42,628,468])

add_block('built-in/Outport',[sys,'/',['Perturbations',13,'arodynamiques/out_1']])
set_param([sys,'/',['Perturbations',13,'arodynamiques/out_1']],...
		'position',[235,85,255,105])

add_block('built-in/Mux',[sys,'/',['Perturbations',13,'arodynamiques/Mux']])
set_param([sys,'/',['Perturbations',13,'arodynamiques/Mux']],...
		'inputs','3',...
		'position',[150,57,180,133])

add_block('built-in/Constant',[sys,'/',['Perturbations',13,'arodynamiques/Constant1']])
set_param([sys,'/',['Perturbations',13,'arodynamiques/Constant1']],...
		'hide name',0,...
		'Value','0',...
		'position',[40,60,85,80])

add_block('built-in/Constant',[sys,'/',['Perturbations',13,'arodynamiques/Constant2']])
set_param([sys,'/',['Perturbations',13,'arodynamiques/Constant2']],...
		'hide name',0,...
		'Value','5e-6',...
		'position',[40,85,85,105])

add_block('built-in/Constant',[sys,'/',['Perturbations',13,'arodynamiques/Constant3']])
set_param([sys,'/',['Perturbations',13,'arodynamiques/Constant3']],...
		'hide name',0,...
		'Value','0',...
		'position',[40,110,85,130])
add_line([sys,'/',['Perturbations',13,'arodynamiques']],[90,70;140,70])
add_line([sys,'/',['Perturbations',13,'arodynamiques']],[90,95;140,95])
add_line([sys,'/',['Perturbations',13,'arodynamiques']],[90,120;140,120])
add_line([sys,'/',['Perturbations',13,'arodynamiques']],[185,95;225,95])
set_param([sys,'/',['Perturbations',13,'arodynamiques']],...
		'Mask Display','Couples\nperturbateurs Mp')


%     Finished composite block ['Perturbations',13,'arodynamiques'].

set_param([sys,'/',['Perturbations',13,'arodynamiques']],...
		'ForeGround',2,...
		'Font Name','Arial',...
		'Font Size',10,...
		'position',[25,85,125,135])

add_block('built-in/Gain',[sys,'/','Gain'])
set_param([sys,'/','Gain'],...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',10,...
		'position',[150,97,185,123])

add_block('built-in/Note',[sys,'/','Mp'])
set_param([sys,'/','Mp'],...
		'Font Name','Arial',...
		'Font Size',10,...
		'position',[215,90,216,91])

add_block('built-in/Gain',[sys,'/','Gain1'])
set_param([sys,'/','Gain1'],...
		'orientation',2,...
		'BackGround',7,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',10,...
		'Gain','1e5',...
		'position',[115,292,150,318])

add_block('built-in/Note',[sys,'/','GAIN A REGLER'])
set_param([sys,'/','GAIN A REGLER'],...
		'ForeGround',7,...
		'Font Size',12,...
		'position',[105,320,106,321])


%     Subsystem  'UnNamed1'.

new_system([sys,'/','UnNamed1'])
set_param([sys,'/','UnNamed1'],'Location',[4,42,628,468])

add_block('built-in/Inport',[sys,'/','UnNamed1/in_1'])
set_param([sys,'/','UnNamed1/in_1'],...
		'position',[15,130,35,150])

add_block('built-in/To Workspace',[sys,'/','UnNamed1/To Workspace'])
set_param([sys,'/','UnNamed1/To Workspace'],...
		'hide name',0,...
		'mat-name','roulis',...
		'buffer','points_trace',...
		'position',[165,67,215,83])

add_block('built-in/Demux',[sys,'/','UnNamed1/Demux'])
set_param([sys,'/','UnNamed1/Demux'],...
		'hide name',0,...
		'outputs','6',...
		'position',[65,59,105,216])

add_block('built-in/To Workspace',[sys,'/','UnNamed1/To Workspace1'])
set_param([sys,'/','UnNamed1/To Workspace1'],...
		'hide name',0,...
		'mat-name','v_roulis',...
		'buffer','points_trace',...
		'position',[165,92,215,108])

add_block('built-in/To Workspace',[sys,'/','UnNamed1/To Workspace2'])
set_param([sys,'/','UnNamed1/To Workspace2'],...
		'hide name',0,...
		'mat-name','tangage',...
		'buffer','points_trace',...
		'position',[165,117,215,133])

add_block('built-in/To Workspace',[sys,'/','UnNamed1/To Workspace3'])
set_param([sys,'/','UnNamed1/To Workspace3'],...
		'hide name',0,...
		'mat-name','v_tangage',...
		'buffer','points_trace',...
		'position',[165,142,215,158])

add_block('built-in/To Workspace',[sys,'/','UnNamed1/To Workspace4'])
set_param([sys,'/','UnNamed1/To Workspace4'],...
		'hide name',0,...
		'mat-name','lacet',...
		'buffer','points_trace',...
		'position',[165,167,215,183])

add_block('built-in/To Workspace',[sys,'/','UnNamed1/To Workspace5'])
set_param([sys,'/','UnNamed1/To Workspace5'],...
		'hide name',0,...
		'mat-name','v_lacet',...
		'buffer','points_trace',...
		'position',[165,192,215,208])
add_line([sys,'/','UnNamed1'],[40,140;55,140])
add_line([sys,'/','UnNamed1'],[110,75;155,75])
add_line([sys,'/','UnNamed1'],[110,100;155,100])
add_line([sys,'/','UnNamed1'],[110,125;155,125])
add_line([sys,'/','UnNamed1'],[110,150;155,150])
add_line([sys,'/','UnNamed1'],[110,175;155,175])
add_line([sys,'/','UnNamed1'],[110,200;155,200])
set_param([sys,'/','UnNamed1'],...
		'Mask Display','Sortie\nsystme\n(angles et\nvitesses angulaires)')


%     Finished composite block 'UnNamed1'.

set_param([sys,'/','UnNamed1'],...
		'ForeGround',1,...
		'BackGround',4,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',10,...
		'position',[520,189,625,251])

add_block('built-in/To Workspace',[sys,'/','To Workspace'])
set_param([sys,'/','To Workspace'],...
		'ForeGround',3,...
		'BackGround',6,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',10,...
		'mat-name','temps',...
		'buffer','points_trace',...
		'position',[440,97,490,113])

add_block('built-in/Clock',[sys,'/','Clock'])
set_param([sys,'/','Clock'],...
		'ForeGround',3,...
		'BackGround',6,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',10,...
		'position',[375,95,395,115])

add_block('built-in/Demux',[sys,'/','Demux1'])
set_param([sys,'/','Demux1'],...
		'BackGround',3,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',10,...
		'outputs','6',...
		'position',[515,114,535,176])

add_block('built-in/Mux',[sys,'/','Mux'])
set_param([sys,'/','Mux'],...
		'BackGround',3,...
		'inputs','2',...
		'position',[560,110,585,150])

add_block('built-in/Note',[sys,'/',' TANGAGE ET ROULIS'])
set_param([sys,'/',' TANGAGE ET ROULIS'],...
		'ForeGround',3,...
		'Font Name','Arial',...
		'Font Size',10,...
		'position',[580,85,581,86])

add_block('built-in/Demux',[sys,'/','Demux'])
set_param([sys,'/','Demux'],...
		'BackGround',5,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',10,...
		'outputs','6',...
		'position',[525,293,555,332])

add_block('built-in/Scope',[sys,'/','Scope2'])
set_param([sys,'/','Scope2'],...
		'BackGround',5,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',10,...
		'Vgain','1.000000',...
		'Hgain','40000.000000',...
		'Vmax','2.000000',...
		'Hmax','80000.000000')
set_param([sys,'/','Scope2'],...
		'Window',[0,256,623,473])
open_system([sys,'/','Scope2'])
set_param([sys,'/','Scope2'],...
		'position',[580,299,620,341])


%     Subsystem  ['Variables',13,'de commande'].

new_system([sys,'/',['Variables',13,'de commande']])
set_param([sys,'/',['Variables',13,'de commande']],'Location',[4,42,628,468])

add_block('built-in/To Workspace',[sys,'/',['Variables',13,'de commande/To Workspace2']])
set_param([sys,'/',['Variables',13,'de commande/To Workspace2']],...
		'hide name',0,...
		'mat-name','commande_z',...
		'buffer','points_trace',...
		'position',[135,136,215,154])

add_block('built-in/To Workspace',[sys,'/',['Variables',13,'de commande/To Workspace1']])
set_param([sys,'/',['Variables',13,'de commande/To Workspace1']],...
		'hide name',0,...
		'mat-name','commande_y',...
		'buffer','points_trace',...
		'position',[135,106,215,124])

add_block('built-in/Demux',[sys,'/',['Variables',13,'de commande/Demux']])
set_param([sys,'/',['Variables',13,'de commande/Demux']],...
		'hide name',0,...
		'outputs','3',...
		'position',[65,67,105,163])

add_block('built-in/To Workspace',[sys,'/',['Variables',13,'de commande/To Workspace']])
set_param([sys,'/',['Variables',13,'de commande/To Workspace']],...
		'hide name',0,...
		'mat-name','commande_x',...
		'buffer','points_trace',...
		'position',[135,76,215,94])

add_block('built-in/Inport',[sys,'/',['Variables',13,'de commande/in_1']])
set_param([sys,'/',['Variables',13,'de commande/in_1']],...
		'position',[15,105,35,125])
add_line([sys,'/',['Variables',13,'de commande']],[110,145;125,145])
add_line([sys,'/',['Variables',13,'de commande']],[110,115;125,115])
add_line([sys,'/',['Variables',13,'de commande']],[110,85;125,85])
add_line([sys,'/',['Variables',13,'de commande']],[40,115;55,115])
set_param([sys,'/',['Variables',13,'de commande']],...
		'Mask Display','Commande\nde couple\nsur les trois axes')


%     Finished composite block ['Variables',13,'de commande'].

set_param([sys,'/',['Variables',13,'de commande']],...
		'ForeGround',1,...
		'BackGround',4,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',10,...
		'position',[345,137,480,183])

add_block('built-in/Scope',[sys,'/','Scope1'])
set_param([sys,'/','Scope1'],...
		'BackGround',3,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',10,...
		'Vgain','0.150000',...
		'Hgain','40000.000000',...
		'Vmax','0.300000',...
		'Hmax','80000.000000')
set_param([sys,'/','Scope1'],...
		'Window',[0,42,623,259])
open_system([sys,'/','Scope1'])
set_param([sys,'/','Scope1'],...
		'position',[605,109,645,151])

add_block('built-in/Discrete State-space',[sys,'/','Modle discrtis'])
set_param([sys,'/','Modle discrtis'],...
		'ForeGround',1,...
		'BackGround',2,...
		'hide name',0,...
		'A','Asat_d',...
		'B','Bsat_d',...
		'C','eye(Asat_d)',...
		'D','zeros(Bsat_d)',...
		'X0','[0.1 0 0.1 0 0.05 -0.001]''')
set_param([sys,'/','Modle discrtis'],...
		'Sample time','temps_echant',...
		'position',[390,192,490,248])


%     Subsystem  ['Calcul champ magntique',13,'terrestre'].

new_system([sys,'/',['Calcul champ magntique',13,'terrestre']])
set_param([sys,'/',['Calcul champ magntique',13,'terrestre']],'Location',[4,42,628,468])

add_block('built-in/Inport',[sys,'/',['Calcul champ magntique',13,'terrestre/in_1']])
set_param([sys,'/',['Calcul champ magntique',13,'terrestre/in_1']],...
		'position',[10,115,30,135])

add_block('built-in/Outport',[sys,'/',['Calcul champ magntique',13,'terrestre/out_1']])
set_param([sys,'/',['Calcul champ magntique',13,'terrestre/out_1']],...
		'Mask Display','',...
		'position',[515,140,535,160])

add_block('built-in/Note',[sys,'/',['Calcul champ magntique',13,'terrestre/Champ magntique',13,'terrestre',13,'(repre satellite)']])
set_param([sys,'/',['Calcul champ magntique',13,'terrestre/Champ magntique',13,'terrestre',13,'(repre satellite)']],...
		'position',[511,190,512,191])

add_block('built-in/MATLAB Fcn',[sys,'/',['Calcul champ magntique',13,'terrestre/MATLAB Fcn']])
set_param([sys,'/',['Calcul champ magntique',13,'terrestre/MATLAB Fcn']],...
		'hide name',0,...
		'MATLAB Fcn','passage(u)',...
		'Output Width','3',...
		'Mask Display','CHANGEMENT\nDE BASE',...
		'position',[390,127,490,173])

add_block('built-in/Mux',[sys,'/',['Calcul champ magntique',13,'terrestre/Mux4']])
set_param([sys,'/',['Calcul champ magntique',13,'terrestre/Mux4']],...
		'hide name',0,...
		'inputs','[3 3]',...
		'position',[325,100,360,195])

add_block('built-in/To Workspace',[sys,'/',['Calcul champ magntique',13,'terrestre/To Workspace']])
set_param([sys,'/',['Calcul champ magntique',13,'terrestre/To Workspace']],...
		'ForeGround',3,...
		'BackGround',4,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',10,...
		'mat-name','angles_bruites')
set_param([sys,'/',['Calcul champ magntique',13,'terrestre/To Workspace']],...
		'buffer','points_trace',...
		'position',[330,230,445,280])

add_block('built-in/Note',[sys,'/',['Calcul champ magntique',13,'terrestre/Champ magntique',13,'terrestre',13,'(repre orbital)']])
set_param([sys,'/',['Calcul champ magntique',13,'terrestre/Champ magntique',13,'terrestre',13,'(repre orbital)']],...
		'position',[170,65,171,66])


%     Subsystem  ['Calcul champ magntique',13,'terrestre/Vecteur bruit'].

new_system([sys,'/',['Calcul champ magntique',13,'terrestre/Vecteur bruit']])
set_param([sys,'/',['Calcul champ magntique',13,'terrestre/Vecteur bruit']],'Location',[4,95,509,460])

add_block('built-in/Demux',[sys,'/',['Calcul champ magntique',13,'terrestre/Vecteur bruit/Demux']])
set_param([sys,'/',['Calcul champ magntique',13,'terrestre/Vecteur bruit/Demux']],...
		'outputs','3',...
		'position',[105,81,160,339])

add_block('built-in/Inport',[sys,'/',['Calcul champ magntique',13,'terrestre/Vecteur bruit/in_1']])
set_param([sys,'/',['Calcul champ magntique',13,'terrestre/Vecteur bruit/in_1']],...
		'position',[55,200,75,220])

add_block('built-in/Outport',[sys,'/',['Calcul champ magntique',13,'terrestre/Vecteur bruit/out_1']])
set_param([sys,'/',['Calcul champ magntique',13,'terrestre/Vecteur bruit/out_1']],...
		'position',[470,200,490,220])


%     Subsystem  ['Calcul champ magntique',13,'terrestre/Vecteur bruit/Bruit de mesure',13,'(coeff_bruit)'].

new_system([sys,'/',['Calcul champ magntique',13,'terrestre/Vecteur bruit/Bruit de mesure',13,'(coeff_bruit)']])
set_param([sys,'/',['Calcul champ magntique',13,'terrestre/Vecteur bruit/Bruit de mesure',13,'(coeff_bruit)']],'Location',[4,127,239,312])

add_block('built-in/White Noise',[sys,'/',['Calcul champ magntique',13,'terrestre/Vecteur bruit/Bruit de mesure',13,'(coeff_bruit)/White Noise']])
set_param([sys,'/',['Calcul champ magntique',13,'terrestre/Vecteur bruit/Bruit de mesure',13,'(coeff_bruit)/White Noise']],...
		'position',[80,65,100,85])

add_block('built-in/Constant',[sys,'/',['Calcul champ magntique',13,'terrestre/Vecteur bruit/Bruit de mesure',13,'(coeff_bruit)/Constant']])
set_param([sys,'/',['Calcul champ magntique',13,'terrestre/Vecteur bruit/Bruit de mesure',13,'(coeff_bruit)/Constant']],...
		'Value','coeff_bruit',...
		'position',[45,105,115,135])

add_block('built-in/Product',[sys,'/',['Calcul champ magntique',13,'terrestre/Vecteur bruit/Bruit de mesure',13,'(coeff_bruit)/Product']])
set_param([sys,'/',['Calcul champ magntique',13,'terrestre/Vecteur bruit/Bruit de mesure',13,'(coeff_bruit)/Product']],...
		'position',[140,54,170,141])

add_block('built-in/Outport',[sys,'/',['Calcul champ magntique',13,'terrestre/Vecteur bruit/Bruit de mesure',13,'(coeff_bruit)/out_1']])
set_param([sys,'/',['Calcul champ magntique',13,'terrestre/Vecteur bruit/Bruit de mesure',13,'(coeff_bruit)/out_1']],...
		'position',[200,90,220,110])
add_line([sys,'/',['Calcul champ magntique',13,'terrestre/Vecteur bruit/Bruit de mesure',13,'(coeff_bruit)']],[120,120;130,120])
add_line([sys,'/',['Calcul champ magntique',13,'terrestre/Vecteur bruit/Bruit de mesure',13,'(coeff_bruit)']],[105,75;130,75])
add_line([sys,'/',['Calcul champ magntique',13,'terrestre/Vecteur bruit/Bruit de mesure',13,'(coeff_bruit)']],[175,100;190,100])
set_param([sys,'/',['Calcul champ magntique',13,'terrestre/Vecteur bruit/Bruit de mesure',13,'(coeff_bruit)']],...
		'Mask Display','BRUIT')


%     Finished composite block ['Calcul champ magntique',13,'terrestre/Vecteur bruit/Bruit de mesure',13,'(coeff_bruit)'].

set_param([sys,'/',['Calcul champ magntique',13,'terrestre/Vecteur bruit/Bruit de mesure',13,'(coeff_bruit)']],...
		'position',[15,15,90,55])

add_block('built-in/Product',[sys,'/',['Calcul champ magntique',13,'terrestre/Vecteur bruit/Product']])
set_param([sys,'/',['Calcul champ magntique',13,'terrestre/Vecteur bruit/Product']],...
		'position',[295,117,330,153])

add_block('built-in/Constant',[sys,'/',['Calcul champ magntique',13,'terrestre/Vecteur bruit/Constant']])
set_param([sys,'/',['Calcul champ magntique',13,'terrestre/Vecteur bruit/Constant']],...
		'position',[140,45,175,65])

add_block('built-in/Sum',[sys,'/',['Calcul champ magntique',13,'terrestre/Vecteur bruit/Sum3']])
set_param([sys,'/',['Calcul champ magntique',13,'terrestre/Vecteur bruit/Sum3']],...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',10,...
		'position',[200,25,220,65])

add_block('built-in/Product',[sys,'/',['Calcul champ magntique',13,'terrestre/Vecteur bruit/Product2']])
set_param([sys,'/',['Calcul champ magntique',13,'terrestre/Vecteur bruit/Product2']],...
		'position',[290,267,325,303])

add_block('built-in/Mux',[sys,'/',['Calcul champ magntique',13,'terrestre/Vecteur bruit/Mux']])
set_param([sys,'/',['Calcul champ magntique',13,'terrestre/Vecteur bruit/Mux']],...
		'inputs','3',...
		'position',[390,95,440,325])

add_block('built-in/Product',[sys,'/',['Calcul champ magntique',13,'terrestre/Vecteur bruit/Product1']])
set_param([sys,'/',['Calcul champ magntique',13,'terrestre/Vecteur bruit/Product1']],...
		'position',[285,182,320,218])
add_line([sys,'/',['Calcul champ magntique',13,'terrestre/Vecteur bruit']],[330,285;380,285])
add_line([sys,'/',['Calcul champ magntique',13,'terrestre/Vecteur bruit']],[165,295;280,295])
add_line([sys,'/',['Calcul champ magntique',13,'terrestre/Vecteur bruit']],[165,210;275,210])
add_line([sys,'/',['Calcul champ magntique',13,'terrestre/Vecteur bruit']],[165,125;285,125])
add_line([sys,'/',['Calcul champ magntique',13,'terrestre/Vecteur bruit']],[80,210;95,210])
add_line([sys,'/',['Calcul champ magntique',13,'terrestre/Vecteur bruit']],[445,210;460,210])
add_line([sys,'/',['Calcul champ magntique',13,'terrestre/Vecteur bruit']],[335,135;380,135])
add_line([sys,'/',['Calcul champ magntique',13,'terrestre/Vecteur bruit']],[95,35;190,35])
add_line([sys,'/',['Calcul champ magntique',13,'terrestre/Vecteur bruit']],[180,55;190,55])
add_line([sys,'/',['Calcul champ magntique',13,'terrestre/Vecteur bruit']],[225,45;250,45;245,275;280,275])
add_line([sys,'/',['Calcul champ magntique',13,'terrestre/Vecteur bruit']],[248,145;285,145])
add_line([sys,'/',['Calcul champ magntique',13,'terrestre/Vecteur bruit']],[247,190;275,190])
add_line([sys,'/',['Calcul champ magntique',13,'terrestre/Vecteur bruit']],[325,200;380,210])
set_param([sys,'/',['Calcul champ magntique',13,'terrestre/Vecteur bruit']],...
		'Mask Display','VECTEUR BRUITE\nj(Coeff_bruit)')


%     Finished composite block ['Calcul champ magntique',13,'terrestre/Vecteur bruit'].

set_param([sys,'/',['Calcul champ magntique',13,'terrestre/Vecteur bruit']],...
		'ForeGround',1,...
		'BackGround',4,...
		'position',[155,144,290,196])

add_block('built-in/Note',[sys,'/',['Calcul champ magntique',13,'terrestre/Vecteur',13,'d''tat']])
set_param([sys,'/',['Calcul champ magntique',13,'terrestre/Vecteur',13,'d''tat']],...
		'position',[33,195,34,196])

add_block('built-in/Inport',[sys,'/',['Calcul champ magntique',13,'terrestre/in_2']])
set_param([sys,'/',['Calcul champ magntique',13,'terrestre/in_2']],...
		'Port','2',...
		'position',[15,160,35,180])

add_block('built-in/State-space',[sys,'/',['Calcul champ magntique',13,'terrestre/Matrix gain.4']])
set_param([sys,'/',['Calcul champ magntique',13,'terrestre/Matrix gain.4']],...
		'A','[]',...
		'B','[]',...
		'C','[]',...
		'D','K',...
		'Mask Display','matrice',...
		'Mask Type','Matrix gain')
set_param([sys,'/',['Calcul champ magntique',13,'terrestre/Matrix gain.4']],...
		'Mask Dialogue','Matrix Gain:|Gain matrix:',...
		'Mask Translate','K = @1;',...
		'Mask Help','Multiplies input vector by entered matrix to produce output vector.')
set_param([sys,'/',['Calcul champ magntique',13,'terrestre/Matrix gain.4']],...
		'Mask Entries','[1 0 0 0 0 0;0 0 1 0 0 0 ;0 0 0 0 1 0]\/',...
		'position',[75,153,130,187])
add_line([sys,'/',['Calcul champ magntique',13,'terrestre']],[35,125;315,125])
add_line([sys,'/',['Calcul champ magntique',13,'terrestre']],[40,170;65,170])
add_line([sys,'/',['Calcul champ magntique',13,'terrestre']],[365,150;380,150])
add_line([sys,'/',['Calcul champ magntique',13,'terrestre']],[495,150;505,150])
add_line([sys,'/',['Calcul champ magntique',13,'terrestre']],[135,170;145,170])
add_line([sys,'/',['Calcul champ magntique',13,'terrestre']],[295,170;315,170])
add_line([sys,'/',['Calcul champ magntique',13,'terrestre']],[295,170;300,255;320,255])
set_param([sys,'/',['Calcul champ magntique',13,'terrestre']],...
		'Mask Display','Calcul du champ\nmagntique terrestre\n(repre satellite)')


%     Finished composite block ['Calcul champ magntique',13,'terrestre'].

set_param([sys,'/',['Calcul champ magntique',13,'terrestre']],...
		'orientation',2,...
		'BackGround',7,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',10,...
		'position',[350,260,485,315])

add_block('built-in/To File',[sys,'/','To File'])
set_param([sys,'/','To File'],...
		'orientation',2,...
		'ForeGround',1,...
		'BackGround',4,...
		'File name','res_derz.mat',...
		'Matrix name','simuz',...
		'position',[355,346,455,384])


%     Subsystem  'UnNamed'.

new_system([sys,'/','UnNamed'])
set_param([sys,'/','UnNamed'],'Location',[50,5439615,480,5439810])

add_block('built-in/Constant',[sys,'/','UnNamed/Constant3'])
set_param([sys,'/','UnNamed/Constant3'],...
		'hide name',0,...
		'Value','rayon_orbital',...
		'position',[65,129,155,161])

add_block('built-in/Constant',[sys,'/','UnNamed/Constant2'])
set_param([sys,'/','UnNamed/Constant2'],...
		'hide name',0,...
		'Value','inclinaison',...
		'position',[65,89,155,121])

add_block('built-in/MATLAB Fcn',[sys,'/','UnNamed/MATLAB Fcn'])
set_param([sys,'/','UnNamed/MATLAB Fcn'],...
		'MATLAB Fcn','champmgn(u)',...
		'position',[270,77,395,133])

add_block('built-in/Clock',[sys,'/','UnNamed/Clock'])
set_param([sys,'/','UnNamed/Clock'],...
		'position',[65,55,85,75])

add_block('built-in/Mux',[sys,'/','UnNamed/Mux'])
set_param([sys,'/','UnNamed/Mux'],...
		'inputs','3',...
		'position',[210,48,250,162])

add_block('built-in/Note',[sys,'/','UnNamed/Temps'])
set_param([sys,'/','UnNamed/Temps'],...
		'position',[125,50,126,51])

add_block('built-in/Outport',[sys,'/','UnNamed/out_1'])
set_param([sys,'/','UnNamed/out_1'],...
		'position',[415,95,435,115])
add_line([sys,'/','UnNamed'],[255,105;260,105])
add_line([sys,'/','UnNamed'],[160,145;200,145])
add_line([sys,'/','UnNamed'],[90,65;200,65])
add_line([sys,'/','UnNamed'],[160,105;200,105])
add_line([sys,'/','UnNamed'],[400,105;405,105])
set_param([sys,'/','UnNamed'],...
		'Mask Display','CHAMP TERRESTRE\nEN REPERE ORBITAL')


%     Finished composite block 'UnNamed'.

set_param([sys,'/','UnNamed'],...
		'orientation',2,...
		'hide name',0,...
		'position',[520,258,625,292])
add_line(sys,[160,215;170,215])
add_line(sys,[90,210;125,210])
add_line(sys,[515,275;495,275])
add_line(sys,[400,105;430,105])
add_line(sys,[130,110;140,110])
add_line(sys,[190,110;285,110;285,210;295,210])
add_line(sys,[270,230;295,230])
add_line(sys,[270,230;270,160;335,160])
add_line(sys,[495,220;510,220])
add_line(sys,[505,220;505,300;495,300])
add_line(sys,[505,220;505,145])
add_line(sys,[590,130;595,130])
add_line(sys,[540,120;550,120])
add_line(sys,[540,140;550,140])
add_line(sys,[345,290;280,290])
add_line(sys,[505,300;475,300;475,320;280,320])
add_line(sys,[345,290;345,265;150,265;150,240;170,240])
add_line(sys,[560,320;570,320])
add_line(sys,[475,315;515,315])
add_line(sys,[170,305;160,305])
add_line(sys,[90,235;90,220;125,220])
add_line(sys,[505,315;505,365;465,365])
add_line(sys,[90,220;90,170;155,170])
add_line(sys,[110,305;90,305;90,295])
add_line(sys,[330,220;335,220;380,220;380,220])

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str] = feval(sys);
	end
end
